@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -363,6 +363,9 @@ class CControllerAuthenticationUpdate extends CController {
 				CMessageHelper::setErrorTitle(_('Cannot update authentication'));
 			}
 		}
+		else {
+			CMessageHelper::setSuccessTitle(_('Authentication settings updated'));
+		}
 
 		$this->setResponse($this->response);
 	}
