@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -35,9 +35,10 @@ class CControllerDashboardShareEdit extends CController {
 		$ret = $this->validateInput($fields);
 
 		if (!$ret) {
-			$errors = CJs::encodeJson(['errors' => [getMessages()->toString()]]);
 			$this->setResponse(
-				(new CControllerResponseData(['main_block' => $errors]))->disableView()
+				(new CControllerResponseData([
+					'main_block' => json_encode(['errors' => getMessages()->toString()])
+				]))->disableView()
 			);
 		}
 
@@ -45,11 +46,16 @@ class CControllerDashboardShareEdit extends CController {
 	}
 
 	protected function checkPermissions() {
+		if (!$this->checkAccess(CRoleHelper::UI_MONITORING_DASHBOARD)
+				|| !$this->checkAccess(CRoleHelper::ACTIONS_EDIT_DASHBOARDS)) {
+			return false;
+		}
+
 		$dashboards = API::Dashboard()->get([
 			'output' => ['dashboardid', 'private'],
 			'selectUsers' => ['userid', 'permission'],
 			'selectUserGroups' => ['usrgrpid', 'permission'],
-			'dashboardids' => $this->getInput('dashboardid'),
+			'dashboardids' => [$this->getInput('dashboardid')],
 			'editable' => true
 		]);
 
@@ -75,7 +81,7 @@ class CControllerDashboardShareEdit extends CController {
 
 			$this->setResponse(
 				(new CControllerResponseData([
-					'main_block' => CJs::encodeJson(['errors' => [getMessages()->toString()]])
+					'main_block' => json_encode(['errors' => [getMessages()->toString()]])
 				]))->disableView()
 			);
 		}
@@ -94,14 +100,14 @@ class CControllerDashboardShareEdit extends CController {
 		$users = zbx_toHash($users, 'userid');
 
 		$db_users = API::User()->get([
-			'output' => ['userid', 'alias', 'name', 'surname'],
+			'output' => ['userid', 'username', 'name', 'surname'],
 			'userids' => array_keys($users)
 		]);
 
 		$result = [];
 		foreach ($db_users as $db_user) {
 			$result[] = [
-				'id'   => $db_user['userid'],
+				'id' => $db_user['userid'],
 				'name' => getUserFullname($db_user),
 				'permission' => $users[$db_user['userid']]['permission']
 			];
