@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@ class CControllerExport extends CController {
 			'valuemapids' =>	'not_empty|array_db valuemaps.valuemapid',
 			'hosts' =>			'not_empty|array_db hosts.hostid',
 			'mediatypeids' =>	'not_empty|array_db media_type.mediatypeid',
-			'screens' =>		'not_empty|array_db screens.screenid',
 			'maps' =>			'not_empty|array_db sysmaps.sysmapid',
 			'templates' =>		'not_empty|array_db hosts.hostid',
 			'format' =>			'in '.implode(',', [CExportWriterFactory::YAML, CExportWriterFactory::XML, CExportWriterFactory::JSON])
@@ -57,9 +56,6 @@ class CControllerExport extends CController {
 			case 'export.templates':
 				return $this->checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES);
 
-			case 'export.screens':
-				return $this->checkAccess(CRoleHelper::UI_MONITORING_SCREENS);
-
 			case 'export.sysmaps':
 				return $this->checkAccess(CRoleHelper::UI_MONITORING_MAPS);
 
@@ -89,10 +85,6 @@ class CControllerExport extends CController {
 				$params['options']['mediaTypes'] = $this->getInput('mediatypeids', []);
 				break;
 
-			case 'export.screens':
-				$params['options']['screens'] = $this->getInput('screens', []);
-				break;
-
 			case 'export.sysmaps':
 				$params['options']['maps'] = $this->getInput('maps', []);
 				break;
