@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -1219,6 +1219,17 @@ abstract class CControllerPopupItemTest extends CController {
 						? $macros_posted[$macro]
 						: '';
 
+					if ($inputs['type'] == ITEM_TYPE_HTTPAGENT && $field === 'posts') {
+						if ($inputs['post_type'] == ZBX_POSTTYPE_JSON && !is_numeric($macro_value)) {
+							$macro_value = json_encode($macro_value, JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE);
+							// Remove " wrapping.
+							$macro_value = substr($macro_value, 1, -1);
+						}
+						elseif ($inputs['post_type'] == ZBX_POSTTYPE_XML) {
+							$macro_value = htmlentities($macro_value);
+						}
+					}
+
 					$inputs[$field] = substr_replace($inputs[$field], $macro_value, $pos, strlen($macro));
 				}
 			}
