@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ class CControllerProxyHostDisable extends CController {
 	}
 
 	protected function checkPermissions() {
-		if ($this->getUserType() != USER_TYPE_SUPER_ADMIN) {
+		if (!$this->checkAccess(CRoleHelper::UI_ADMINISTRATION_PROXIES)) {
 			return false;
 		}
 
@@ -63,7 +63,7 @@ class CControllerProxyHostDisable extends CController {
 		}
 		unset($host);
 
-		$result = API::Host()->update($hosts);
+		$result = $hosts ? (bool) API::Host()->update($hosts) : true;
 
 		$updated = count($hosts);
 
@@ -74,10 +74,10 @@ class CControllerProxyHostDisable extends CController {
 
 		if ($result) {
 			$response->setFormData(['uncheck' => '1']);
-			$response->setMessageOk(_n('Host disabled', 'Hosts disabled', $updated));
+			CMessageHelper::setSuccessTitle(_n('Host disabled', 'Hosts disabled', $updated));
 		}
 		else {
-			$response->setMessageError(_n('Cannot disable host', 'Cannot disable hosts', $updated));
+			CMessageHelper::setErrorTitle(_n('Cannot disable host', 'Cannot disable hosts', $updated));
 		}
 		$this->setResponse($response);
 	}
