@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,13 +27,13 @@ class CControllerUserList extends CController {
 
 	protected function checkInput() {
 		$fields = [
-			'sort' =>				'in alias,name,surname,role_name',
+			'sort' =>				'in username,name,surname,role_name',
 			'sortorder' =>			'in '.ZBX_SORT_DOWN.','.ZBX_SORT_UP,
 			'uncheck' =>			'in 1',
 			'filter_set' =>			'in 1',
 			'filter_rst' =>			'in 1',
 			'filter_usrgrpid' =>	'db usrgrp.usrgrpid',
-			'filter_alias' =>		'string',
+			'filter_username' =>	'string',
 			'filter_name' =>		'string',
 			'filter_surname' =>		'string',
 			'filter_roles' =>		'array_id',
@@ -57,26 +57,26 @@ class CControllerUserList extends CController {
 		$filter_usrgrpid = $this->getInput('filter_usrgrpid', CProfile::get('web.user.filter.usrgrpid', 0));
 		CProfile::update('web.user.filter.usrgrpid', $filter_usrgrpid, PROFILE_TYPE_ID);
 
-		$sortfield = $this->getInput('sort', CProfile::get('web.user.sort', 'alias'));
+		$sortfield = $this->getInput('sort', CProfile::get('web.user.sort', 'username'));
 		$sortorder = $this->getInput('sortorder', CProfile::get('web.user.sortorder', ZBX_SORT_UP));
 		CProfile::update('web.user.sort', $sortfield, PROFILE_TYPE_STR);
 		CProfile::update('web.user.sortorder', $sortorder, PROFILE_TYPE_STR);
 
 		if ($this->hasInput('filter_set')) {
-			CProfile::update('web.user.filter_alias', $this->getInput('filter_alias', ''), PROFILE_TYPE_STR);
+			CProfile::update('web.user.filter_username', $this->getInput('filter_username', ''), PROFILE_TYPE_STR);
 			CProfile::update('web.user.filter_name', $this->getInput('filter_name', ''), PROFILE_TYPE_STR);
 			CProfile::update('web.user.filter_surname', $this->getInput('filter_surname', ''), PROFILE_TYPE_STR);
 			CProfile::updateArray('web.user.filter_roles', $this->getInput('filter_roles', []), PROFILE_TYPE_ID);
 		}
 		elseif ($this->hasInput('filter_rst')) {
-			CProfile::delete('web.user.filter_alias');
+			CProfile::delete('web.user.filter_username');
 			CProfile::delete('web.user.filter_name');
 			CProfile::delete('web.user.filter_surname');
 			CProfile::deleteIdx('web.user.filter_roles');
 		}
 
 		$filter = [
-			'alias' => CProfile::get('web.user.filter_alias', ''),
+			'username' => CProfile::get('web.user.filter_username', ''),
 			'name' => CProfile::get('web.user.filter_name', ''),
 			'surname' => CProfile::get('web.user.filter_surname', ''),
 			'roles' => CProfile::getArray('web.user.filter_roles', [])
@@ -114,11 +114,11 @@ class CControllerUserList extends CController {
 
 		$limit = CSettingsHelper::get(CSettingsHelper::SEARCH_LIMIT) + 1;
 		$data['users'] = API::User()->get([
-			'output' => ['userid', 'alias', 'name', 'surname', 'autologout', 'attempt_failed', 'roleid'],
+			'output' => ['userid', 'username', 'name', 'surname', 'autologout', 'attempt_failed', 'roleid'],
 			'selectUsrgrps' => ['name', 'gui_access', 'users_status'],
 			'selectRole' => ['name'],
 			'search' => [
-				'alias' => ($filter['alias'] === '') ? null : $filter['alias'],
+				'username' => ($filter['username'] === '') ? null : $filter['username'],
 				'name' => ($filter['name'] === '') ? null : $filter['name'],
 				'surname' => ($filter['surname'] === '') ? null : $filter['surname']
 			],
