@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,16 +31,6 @@ $form = (new CForm('GET', 'history.php'))
 $table = (new CTableInfo())->addClass(ZBX_STYLE_OVERFLOW_ELLIPSIS);
 
 // Latest data header.
-
-$col_toggle_all = new CColHeader(
-	(new CSimpleButton())
-		->addClass(ZBX_STYLE_TREEVIEW)
-		->addClass('js-toggle-all')
-		->addItem(
-			(new CSpan())->addClass($data['collapsed_all'] ? ZBX_STYLE_ARROW_RIGHT : ZBX_STYLE_ARROW_DOWN)
-		)
-);
-
 $col_check_all = new CColHeader(
 	(new CCheckBox('all_items'))->onClick("checkAll('".$form->getName()."', 'all_items', 'itemids');")
 );
@@ -50,9 +40,11 @@ $view_url = $data['view_curl']->getUrl();
 $col_host = make_sorting_header(_('Host'), 'host', $data['sort_field'], $data['sort_order'], $view_url);
 $col_name = make_sorting_header(_('Name'), 'name', $data['sort_field'], $data['sort_order'], $view_url);
 
+$simple_interval_parser = new CSimpleIntervalParser();
+$update_interval_parser = new CUpdateIntervalParser(['usermacros' => true]);
+
 if ($data['filter']['show_details']) {
 	$table->setHeader([
-		$col_toggle_all->addStyle('width: 18px'),
 		$col_check_all->addStyle('width: 15px;'),
 		$col_host->addStyle('width: 13%'),
 		$col_name->addStyle('width: 21%'),
@@ -63,109 +55,42 @@ if ($data['filter']['show_details']) {
 		(new CColHeader(_('Last check')))->addStyle('width: 14%'),
 		(new CColHeader(_('Last value')))->addStyle('width: 14%'),
 		(new CColHeader(_x('Change', 'noun')))->addStyle('width: 10%'),
-		(new CColHeader())->addStyle('width: 5%'),
+		(new CColHeader(_('Tags')))->addClass(ZBX_STYLE_COLUMN_TAGS_3),
+		(new CColHeader())->addStyle('width: 6%'),
 		(new CColHeader(_('Info')))->addStyle('width: 35px')
 	]);
-
-	$table_columns = 13;
 }
 else {
 	$table->setHeader([
-		$col_toggle_all->addStyle('width: 18px'),
 		$col_check_all->addStyle('width: 15px'),
 		$col_host->addStyle('width: 17%'),
 		$col_name->addStyle('width: 40%'),
 		(new CColHeader(_('Last check')))->addStyle('width: 14%'),
 		(new CColHeader(_('Last value')))->addStyle('width: 14%'),
 		(new CColHeader(_x('Change', 'noun')))->addStyle('width: 10%'),
-		(new CColHeader())->addStyle('width: 5%')
+		(new CColHeader(_('Tags')))->addClass(ZBX_STYLE_COLUMN_TAGS_3),
+		(new CColHeader())->addStyle('width: 6%')
 	]);
-
-	$table_columns = 8;
 }
 
 // Latest data rows.
+foreach ($data['items'] as $itemid => $item) {
+	$is_graph = ($item['value_type'] == ITEM_VALUE_TYPE_FLOAT || $item['value_type'] == ITEM_VALUE_TYPE_UINT64);
+	$checkbox = (new CCheckBox('itemids['.$itemid.']', $itemid))->setEnabled($is_graph);
+	$state_css = ($item['state'] == ITEM_STATE_NOTSUPPORTED) ? ZBX_STYLE_GREY : null;
 
-$simple_interval_parser = new CSimpleIntervalParser();
-$update_interval_parser = new CUpdateIntervalParser(['usermacros' => true]);
-
-$last_hostid = null;
-$last_applicationid = null;
-
-$last_row_index = $data['rows'] ? array_slice(array_keys($data['rows']), -1)[0] : null;
-
-foreach ($data['rows'] as $row_index => $row) {
-	$item = $data['items'][$row['itemid']];
-
-	$is_collapsed = $data['collapsed_index'][$item['hostid']][$row['applicationid']];
-
-	// Secondary header for the next host or application.
-
-	$is_next_host = $item['hostid'] !== $last_hostid;
-	$is_next_application = $row['applicationid'] !== $last_applicationid;
-
-	if ($is_next_host || $is_next_application) {
-		$host = $data['hosts'][$item['hostid']];
-
-		$col_host = (new CLinkAction($host['name']))->setMenuPopup(CMenuPopupHelper::getHost($item['hostid']));
-
-		if ($host['status'] == HOST_STATUS_NOT_MONITORED) {
-			$col_host->addClass(ZBX_STYLE_RED);
-		}
-
-		$application_name = $row['applicationid']
-			? $data['applications'][$row['applicationid']]['name']
-			: '- '.('other').' -';
-
-		$application_size = $data['applications_size'][$item['hostid']][$row['applicationid']];
-		$application_index = $data['applications_index'][$item['hostid']][$row['applicationid']];
-
-		if ($application_index['start'] < $row_index || $application_index['end'] > $last_row_index) {
-			$application_stats = _s('displaying %1$s to %2$s of %3$s Items',
-				max(0, $row_index - $application_index['start']) + 1,
-				min($last_row_index, $application_index['end']) - $application_index['start'] + 1,
-				$application_size
-			);
-		}
-		else {
-			$application_stats = _n('%1$s Item', '%1$s Items', $application_size);
-		}
-
-		$col_name = (new CCol([bold($application_name), ' ('.$application_stats.')']))
-			->setColSpan($table_columns - 2);
-
-		$toggle_app = (new CSimpleButton())
-			->addClass(ZBX_STYLE_TREEVIEW)
-			->addClass('js-toggle')
-			->addItem(
-				(new CSpan())->addClass($is_collapsed ? ZBX_STYLE_ARROW_RIGHT : ZBX_STYLE_ARROW_DOWN)
-			);
-
-		if ($row['applicationid']) {
-			$toggle_app->setAttribute('data-applicationid', $row['applicationid']);
-		}
-		else {
-			$toggle_app->setAttribute('data-hostid', $item['hostid']);
-		}
-
-		$table->addRow([$toggle_app, '', $col_host, $col_name]);
-
-		$last_hostid = $item['hostid'];
-		$last_applicationid = $row['applicationid'];
-	}
+	$item_name = (new CDiv([
+		(new CSpan($item['name_expanded']))->addClass('label'),
+		($item['description'] !== '') ? makeDescriptionIcon($item['description']) : null
+	]))->addClass('action-container');
 
 	// Row history data preparation.
-
-	if (array_key_exists($item['itemid'], $data['history'])) {
-		$last_history = (count($data['history'][$item['itemid']]) > 0) ? $data['history'][$item['itemid']][0] : null;
-		$prev_history = (count($data['history'][$item['itemid']]) > 1) ? $data['history'][$item['itemid']][1] : null;
-	}
-	else {
-		$last_history = null;
-		$prev_history = null;
-	}
+	$last_history = array_key_exists($itemid, $data['history'])
+		? ((count($data['history'][$itemid]) > 0) ? $data['history'][$itemid][0] : null)
+		: null;
 
 	if ($last_history) {
+		$prev_history = (count($data['history'][$itemid]) > 1) ? $data['history'][$itemid][1] : null;
 		$last_check = zbx_date2str(DATE_TIME_FORMAT_SECONDS, $last_history['clock']);
 		$last_value = formatHistoryValue($last_history['value'], $item, false);
 		$change = '';
@@ -193,7 +118,6 @@ foreach ($data['rows'] as $row_index => $row) {
 	}
 
 	// Other row data preparation.
-
 	if ($data['config']['hk_history_global']) {
 		$keep_history = timeUnitToSeconds($data['config']['hk_history']);
 		$item_history = $data['config']['hk_history'];
@@ -226,15 +150,6 @@ foreach ($data['rows'] as $row_index => $row) {
 		$item_trends = '';
 	}
 
-	$is_graph = ($item['value_type'] == ITEM_VALUE_TYPE_FLOAT || $item['value_type'] == ITEM_VALUE_TYPE_UINT64);
-
-	$checkbox = (new CCheckBox('itemids['.$item['itemid'].']', $item['itemid']))->setEnabled($is_graph);
-
-	$item_name = (new CDiv([
-		(new CSpan($item['name_expanded']))->addClass('label'),
-		($item['description'] !== '') ? makeDescriptionIcon($item['description']) : null
-	]))->addClass('action-container');
-
 	if ($keep_history != 0 || $keep_trends != 0) {
 		$actions = new CLink($is_graph ? _('Graph') : _('History'), (new CUrl('history.php'))
 			->setArgument('action', $is_graph ? HISTORY_GRAPH : HISTORY_VALUES)
@@ -245,20 +160,23 @@ foreach ($data['rows'] as $row_index => $row) {
 		$actions = '';
 	}
 
-	$state_css = ($item['state'] == ITEM_STATE_NOTSUPPORTED) ? ZBX_STYLE_GREY : null;
+	$host = $data['hosts'][$item['hostid']];
+	$host_name = (new CLinkAction($host['name']))
+		->addClass($host['status'] == HOST_STATUS_NOT_MONITORED ? ZBX_STYLE_RED : null)
+		->setMenuPopup(CMenuPopupHelper::getHost($item['hostid']));
 
 	if ($data['filter']['show_details']) {
-		if ($item['type'] == ITEM_TYPE_HTTPTEST) {
-			$item_key = (new CSpan($item['key_expanded']))->addClass(ZBX_STYLE_GREEN);
-		}
-		else {
-			$item_key = (new CLink($item['key_expanded'], (new CUrl('items.php'))
-				->setArgument('form', 'update')
-				->setArgument('itemid', $item['itemid'])
-			))
+
+		$item_config_url = (new CUrl('items.php'))
+			->setArgument('form', 'update')
+			->setArgument('itemid', $itemid)
+			->setArgument('context', 'host');
+
+		$item_key = ($item['type'] == ITEM_TYPE_HTTPTEST)
+			? (new CSpan($item['key_expanded']))->addClass(ZBX_STYLE_GREEN)
+			: (new CLink($item['key_expanded'], $item_config_url))
 				->addClass(ZBX_STYLE_LINK_ALT)
 				->addClass(ZBX_STYLE_GREEN);
-		}
 
 		if (in_array($item['type'], [ITEM_TYPE_SNMPTRAP, ITEM_TYPE_TRAPPER, ITEM_TYPE_DEPENDENT])
 				|| ($item['type'] == ITEM_TYPE_ZABBIX_ACTIVE && strncmp($item['key_expanded'], 'mqtt.get', 8) === 0)) {
@@ -281,9 +199,8 @@ foreach ($data['rows'] as $row_index => $row) {
 		}
 
 		$table_row = new CRow([
-			'',
 			$checkbox,
-			'',
+			$host_name,
 			(new CCol([$item_name, $item_key]))->addClass($state_css),
 			(new CCol($item_delay))->addClass($state_css),
 			(new CCol($item_history))->addClass($state_css),
@@ -292,34 +209,24 @@ foreach ($data['rows'] as $row_index => $row) {
 			(new CCol($last_check))->addClass($state_css),
 			(new CCol($last_value))->addClass($state_css),
 			(new CCol($change))->addClass($state_css),
+			$data['tags'][$itemid],
 			$actions,
 			makeInformationList($item_icons)
 		]);
 	}
 	else {
 		$table_row = new CRow([
-			'',
 			$checkbox,
-			'',
+			$host_name,
 			(new CCol($item_name))->addClass($state_css),
 			(new CCol($last_check))->addClass($state_css),
 			(new CCol($last_value))->addClass($state_css),
 			(new CCol($change))->addClass($state_css),
+			$data['tags'][$itemid],
 			$actions
 		]);
 	}
 
-	if ($row['applicationid']) {
-		$table_row->setAttribute('data-applicationid', $row['applicationid']);
-	}
-	else {
-		$table_row->setAttribute('data-hostid', $item['hostid']);
-	}
-
-	if ($is_collapsed) {
-		$table_row->addClass(ZBX_STYLE_DISPLAY_NONE);
-	}
-
 	$table->addRow($table_row);
 }
 
