@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 if ($data['uncheck']) {
 	uncheckTableRows('mediatype');
 }
@@ -28,6 +32,11 @@ $widget = (new CWidget())
 	->setControls((new CTag('nav', true,
 		(new CList())
 			->addItem(new CRedirectButton(_('Create media type'), 'zabbix.php?action=mediatype.edit'))
+			->addItem(
+				(new CButton('', _('Import')))
+					->onClick('return PopUp("popup.import", {rules_preset: "mediatype"}, null, this);')
+					->removeId()
+			)
 		))
 			->setAttribute('aria-label', _('Content controls'))
 	)
@@ -55,14 +64,18 @@ $widget = (new CWidget())
 $mediaTypeForm = (new CForm())->setName('mediaTypesForm');
 
 // create table
+$url = (new CUrl('zabbix.php'))
+	->setArgument('action', 'mediatype.list')
+	->getUrl();
+
 $mediaTypeTable = (new CTableInfo())
 	->setHeader([
 		(new CColHeader(
 			(new CCheckBox('all_media_types'))
 				->onClick("checkAll('".$mediaTypeForm->getName()."', 'all_media_types', 'mediatypeids');")
 		))->addClass(ZBX_STYLE_CELL_WIDTH),
-		make_sorting_header(_('Name'), 'description', $data['sort'], $data['sortorder']),
-		make_sorting_header(_('Type'), 'type', $data['sort'], $data['sortorder']),
+		make_sorting_header(_('Name'), 'name', $data['sort'], $data['sortorder'], $url),
+		make_sorting_header(_('Type'), 'type', $data['sort'], $data['sortorder'], $url),
 		_('Status'),
 		_('Used in actions'),
 		_('Details'),
@@ -86,14 +99,6 @@ foreach ($data['mediatypes'] as $mediaType) {
 			$details = _('GSM modem').NAME_DELIMITER.'"'.$mediaType['gsm_modem'].'"';
 			break;
 
-		case MEDIA_TYPE_JABBER:
-			$details = _('Jabber identifier').NAME_DELIMITER.'"'.$mediaType['username'].'"';
-			break;
-
-		case MEDIA_TYPE_EZ_TEXTING:
-			$details = _('Username').NAME_DELIMITER.'"'.$mediaType['username'].'"';
-			break;
-
 		default:
 			$details = '';
 			break;
@@ -133,12 +138,13 @@ foreach ($data['mediatypes'] as $mediaType) {
 
 	$test_link = (new CButton('mediatypetest_edit', _('Test')))
 		->addClass(ZBX_STYLE_BTN_LINK)
+		->removeId()
 		->setEnabled(MEDIA_TYPE_STATUS_ACTIVE == $mediaType['status'])
-		->onClick('return PopUp("popup.mediatypetest.edit",'.CJs::encodeJson([
+		->onClick('return PopUp("popup.mediatypetest.edit",'.json_encode([
 			'mediatypeid' => $mediaType['mediatypeid']
 		]).', "mediatypetest_edit", this);');
 
-	$name = new CLink($mediaType['description'], '?action=mediatype.edit&mediatypeid='.$mediaType['mediatypeid']);
+	$name = new CLink($mediaType['name'], '?action=mediatype.edit&mediatypeid='.$mediaType['mediatypeid']);
 
 	// append row
 	$mediaTypeTable->addRow([
@@ -159,6 +165,14 @@ $mediaTypeForm->addItem([
 	new CActionButtonList('action', 'mediatypeids', [
 		'mediatype.enable' => ['name' => _('Enable'), 'confirm' => _('Enable selected media types?')],
 		'mediatype.disable' => ['name' => _('Disable'), 'confirm' => _('Disable selected media types?')],
+		'mediatype.export' => [
+			'content' => new CButtonExport('export.mediatypes',
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'mediatype.list')
+					->setArgument('page', ($data['page'] == 1) ? null : $data['page'])
+					->getUrl()
+			)
+		],
 		'mediatype.delete' => ['name' => _('Delete'), 'confirm' => _('Delete selected media types?')]
 	], 'mediatype')
 ]);
