@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 <script type="text/javascript">
 	jQuery(function($) {
 		let $form = $('form[name="user_form"]').submit(function() {
-			$(this).trimValues(['#alias', '#name', '#surname', '#password1', '#password2', '#autologout', '#refresh',
+			$(this).trimValues(['#username', '#name', '#surname', '#password1', '#password2', '#autologout', '#refresh',
 				'#url'
 			]);
 		});
