@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,9 +24,14 @@
  */
 ?>
 
+<script type="text/x-jquery-tmpl" id="filter-tag-row-tmpl">
+	<?= CTagFilterFieldHelper::getTemplate(); ?>
+</script>
+
 <script type="text/javascript">
 	function latestPage() {
 		this.refresh_url = '<?= $data['refresh_url'] ?>';
+		this.refresh_data = <?= json_encode($data['refresh_data']) ?>;
 		this.refresh_interval = <?= $data['refresh_interval'] ?>;
 		this.running = false;
 		this.timeout = null;
@@ -47,7 +52,12 @@
 	latestPage.prototype.refresh = function() {
 		this.setLoading();
 
-		var deferred = $.getJSON(this.refresh_url);
+		var deferred = $.ajax({
+			url: this.refresh_url,
+			data: this.refresh_data,
+			type: 'post',
+			dataType: 'json'
+		});
 
 		return this.bindDataEvents(deferred);
 	};
@@ -62,7 +72,6 @@
 
 	latestPage.prototype.doRefresh = function(body) {
 		this.getCurrentForm().replaceWith(body);
-		this.liveData();
 		chkbxRange.init();
 	};
 
@@ -142,38 +151,6 @@
 		this.unscheduleRefresh();
 	};
 
-	latestPage.prototype.toggleChevronCollapsed = function($chevron, collapsed) {
-		$chevron
-			.removeClass(collapsed ? '<?= ZBX_STYLE_ARROW_DOWN ?>' : '<?= ZBX_STYLE_ARROW_RIGHT ?>')
-			.addClass(collapsed ? '<?= ZBX_STYLE_ARROW_RIGHT ?>' : '<?= ZBX_STYLE_ARROW_DOWN ?>');
-	};
-
-	latestPage.prototype.isChevronCollapsed = function($chevron) {
-		return $chevron.hasClass('<?= ZBX_STYLE_ARROW_RIGHT ?>');
-	};
-
-	latestPage.prototype.toggleAppGroup = function(group, group_id, collapsed) {
-		var $chevron = $('.js-toggle[data-' + group + '="' + group_id + '"] span'),
-			$rows = $('tr[data-' + group + '="' + group_id + '"]');
-
-		this.toggleChevronCollapsed($chevron, collapsed);
-
-		$rows.toggleClass('<?= ZBX_STYLE_DISPLAY_NONE ?>', collapsed);
-	};
-
-	latestPage.prototype.updateToggleAll = function() {
-		var self = this,
-
-			$chevron_all = $('.js-toggle-all span'),
-			collapsed_all = true;
-
-		$('.js-toggle span').each(function() {
-			collapsed_all = collapsed_all && self.isChevronCollapsed($(this));
-		});
-
-		this.toggleChevronCollapsed($chevron_all, collapsed_all);
-	};
-
 	latestPage.prototype.liveFilter = function() {
 		var $filter_hostids = $('#filter_hostids_'),
 			$filter_show_without_data = $('#filter_show_without_data');
@@ -187,84 +164,22 @@
 
 			$filter_show_without_data.prop('disabled', no_hosts_selected);
 		});
-	};
 
-	latestPage.prototype.liveData = function() {
-		var self = this;
-
-		$('.js-toggle-all').on('click', function() {
-			// For Opera browser with large tables, which renders table layout while showing/hiding rows.
-			$(this).closest('table').fadeTo(0, 0);
-
-			var $toggle_all = $(this),
-				collapsed_all = !self.isChevronCollapsed($toggle_all.find('span')),
-
-				updates = {
-					applicationid: [],
-					hostid: []
-				};
-
-			$('.js-toggle').each(function() {
-				var $toggle = $(this),
-					collapsed = self.isChevronCollapsed($toggle.find('span'));
-
-				if (collapsed == collapsed_all) {
-					return;
-				}
-
-				var group = 'applicationid',
-					group_id = $toggle.data(group);
-
-				if (group_id === undefined) {
-					group = 'hostid',
-					group_id = $toggle.data(group);
-				}
-
-				updates[group].push(group_id);
-
-				self.toggleAppGroup(group, group_id, collapsed_all);
+		$('#filter-tags')
+			.dynamicRows({template: '#filter-tag-row-tmpl'})
+			.on('afteradd.dynamicRows', function() {
+				var rows = this.querySelectorAll('.form_row');
+				new CTagFilterItem(rows[rows.length - 1]);
 			});
 
-			self.updateToggleAll();
-
-			// For Opera browser with large tables, which renders table layout while showing/hiding rows.
-			$(this).closest('table').fadeTo(0, 1);
-
-			if (updates.applicationid.length) {
-				updateUserProfile('web.latest.toggle', collapsed_all ? 0 : 1, updates.applicationid);
-			}
-			if (updates.hostid.length) {
-				updateUserProfile('web.latest.toggle_other', collapsed_all ? 0 : 1, updates.hostid);
-			}
-		});
-
-		$('.js-toggle').on('click', function() {
-			var $toggle = $(this),
-				collapsed = !self.isChevronCollapsed($toggle.find('span')),
-
-				group = 'applicationid',
-				group_id = $toggle.data(group);
-
-			if (group_id === undefined) {
-				group = 'hostid',
-				group_id = $toggle.data(group);
-			}
-
-			self.toggleAppGroup(group, group_id, collapsed);
-			self.updateToggleAll();
-
-			if (group === 'applicationid') {
-				updateUserProfile('web.latest.toggle', collapsed ? 0 : 1, [group_id]);
-			}
-			else {
-				updateUserProfile('web.latest.toggle_other', collapsed ? 0 : 1, [group_id]);
-			}
+		// Init existing fields once loaded.
+		document.querySelectorAll('#filter-tags .form_row').forEach(row => {
+			new CTagFilterItem(row);
 		});
 	};
 
 	$(function() {
 		window.latest_page = new latestPage();
 		window.latest_page.liveFilter();
-		window.latest_page.liveData();
 	});
 </script>
