@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,23 +19,30 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 $table = (new CTableInfo())->setNoDataMessage(_('No maps added.'));
 
 foreach ($data['maps'] as $map) {
 	$table->addRow([
-		new CLink($map['label'], (new CUrl('zabbix.php'))
-			->setArgument('action', 'map.view')
-			->setArgument('sysmapid', $map['sysmapid'])
-		),
+		$data['allowed_ui_maps']
+			? new CLink($map['label'], (new CUrl('zabbix.php'))
+				->setArgument('action', 'map.view')
+				->setArgument('sysmapid', $map['sysmapid'])
+			)
+			: $map['label'],
 		(new CButton())
 			->onClick("rm4favorites('sysmapid','".$map['sysmapid']."')")
 			->addClass(ZBX_STYLE_REMOVE_BTN)
 			->setAttribute('aria-label', _xs('Remove, %1$s', 'screen reader', $map['label']))
+			->removeId()
 	]);
 }
 
 $output = [
-	'header' => $data['name'],
+	'name' => $data['name'],
 	'body' => $table->toString()
 ];
 
@@ -48,4 +55,4 @@ if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
 	$output['debug'] = CProfiler::getInstance()->make()->toString();
 }
 
-echo (new CJson())->encode($output);
+echo json_encode($output);
