@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -46,11 +46,15 @@ switch ($data['type']) {
 		require_once dirname(__FILE__).'/../../include/correlation.inc.php';
 
 		// Type select.
-		$condition_type_combobox = new CComboBox('condition_type', $condition_type,
-			"reloadPopup(this.form, 'popup.condition.event.corr');", corrConditionTypes()
+		$form_list->addRow(new CLabel(_('Type'), 'label-condition-type'), (new CSelect('condition_type'))
+			->setFocusableElementId('label-condition-type')
+			->setValue($condition_type)
+			->setId('condition-type')
+			->addOptions(CSelect::createOptionsFromArray(corrConditionTypes()))
 		);
 
-		$form_list->addRow(_('Type'), $condition_type_combobox);
+		$inline_js .= '$(() => $("#condition-type").on("change",'
+			.'(e) => reloadPopup($(e.target).closest("form").get(0), "popup.condition.event.corr")));';
 
 		switch ($condition_type) {
 			// Old|New event tag form elements.
@@ -143,28 +147,32 @@ switch ($data['type']) {
 		require_once dirname(__FILE__).'/../../include/actions.inc.php';
 
 		// Collect all operators options.
-		$combobox_options = [];
-		$action_condition_options = [];
+		$operators_by_condition = [];
+		$action_conditions = [];
 		foreach ($data['allowed_conditions'] as $type) {
-			$action_condition_options[$type] = condition_type2str($type);
+			$action_conditions[$type] = condition_type2str($type);
 
 			foreach (get_operators_by_conditiontype($type) as $value) {
-				$combobox_options[$type][$value] = condition_operator2str($value);
+				$operators_by_condition[$type][$value] = condition_operator2str($value);
 			}
 		}
 
 		// Type select.
-		$action_condition_type_combobox = new CComboBox('condition_type', $condition_type,
-			"reloadPopup(this.form, 'popup.condition.actions');", $action_condition_options
+		$form_list->addRow(new CLabel(_('Type'), 'label-condition-type'), (new CSelect('condition_type'))
+			->setFocusableElementId('label-condition-type')
+			->setValue($condition_type)
+			->setId('condition-type')
+			->addOptions(CSelect::createOptionsFromArray($action_conditions))
 		);
 
-		$form_list->addRow(_('Type'), $action_condition_type_combobox);
+		$inline_js .= '$(() => $("#condition-type").on("change",'
+			.'(e) => reloadPopup($(e.target).closest("form").get(0), "popup.condition.actions")));';
 
 		switch ($condition_type) {
 			// Trigger form elements.
 			case CONDITION_TYPE_TRIGGER:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_TRIGGER] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_TRIGGER] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 
@@ -196,7 +204,7 @@ switch ($data['type']) {
 			// Trigger severity form elements.
 			case CONDITION_TYPE_TRIGGER_SEVERITY:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_TRIGGER_SEVERITY] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_TRIGGER_SEVERITY] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 
@@ -210,7 +218,7 @@ switch ($data['type']) {
 			// Host form elements.
 			case CONDITION_TYPE_HOST:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_HOST] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_HOST] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 
@@ -241,7 +249,7 @@ switch ($data['type']) {
 			// Host group form elements.
 			case CONDITION_TYPE_HOST_GROUP:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_HOST_GROUP] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_HOST_GROUP] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 
@@ -272,7 +280,7 @@ switch ($data['type']) {
 			// Problem is suppressed form elements.
 			case CONDITION_TYPE_SUPPRESSED:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_NO))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_SUPPRESSED] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_SUPPRESSED] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 
@@ -282,7 +290,7 @@ switch ($data['type']) {
 			// Tag form elements.
 			case CONDITION_TYPE_EVENT_TAG:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_EVENT_TAG] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_EVENT_TAG] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 				$new_condition_value = (new CTextAreaFlexible('value'))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH);
@@ -297,7 +305,7 @@ switch ($data['type']) {
 			// Tag value form elements.
 			case CONDITION_TYPE_EVENT_TAG_VALUE:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_EVENT_TAG_VALUE] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_EVENT_TAG_VALUE] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 				$new_condition_value2 = (new CTextAreaFlexible('value2'))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH);
@@ -315,7 +323,7 @@ switch ($data['type']) {
 			// Template form elements.
 			case CONDITION_TYPE_TEMPLATE:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_TEMPLATE] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_TEMPLATE] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 
@@ -347,7 +355,7 @@ switch ($data['type']) {
 			// Time period form elements.
 			case CONDITION_TYPE_TIME_PERIOD:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_IN))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_TIME_PERIOD] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_TIME_PERIOD] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 
@@ -362,7 +370,7 @@ switch ($data['type']) {
 			// Discovery host ip form elements.
 			case CONDITION_TYPE_DHOST_IP:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_DHOST_IP] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_DHOST_IP] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 
@@ -377,7 +385,7 @@ switch ($data['type']) {
 			// Discovery check form elements.
 			case CONDITION_TYPE_DCHECK:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_DCHECK] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_DCHECK] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 
@@ -412,7 +420,7 @@ switch ($data['type']) {
 				$operator = (new CRadioButtonList('', CONDITION_OPERATOR_EQUAL))
 					->setModern(true)
 					->addValue(
-						$combobox_options[CONDITION_TYPE_DOBJECT][CONDITION_OPERATOR_EQUAL],
+						$operators_by_condition[CONDITION_TYPE_DOBJECT][CONDITION_OPERATOR_EQUAL],
 						CONDITION_OPERATOR_EQUAL
 					);
 				$new_condition_value = (new CRadioButtonList('value', EVENT_OBJECT_DHOST))
@@ -428,7 +436,7 @@ switch ($data['type']) {
 			// Discovery rule form elements.
 			case CONDITION_TYPE_DRULE:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_DRULE] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_DRULE] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 
@@ -460,7 +468,7 @@ switch ($data['type']) {
 				$operator = (new CRadioButtonList('', CONDITION_OPERATOR_EQUAL))
 					->setModern(true)
 					->addValue(
-						$combobox_options[CONDITION_TYPE_DSTATUS][CONDITION_OPERATOR_EQUAL],
+						$operators_by_condition[CONDITION_TYPE_DSTATUS][CONDITION_OPERATOR_EQUAL],
 						CONDITION_OPERATOR_EQUAL
 					);
 				$new_condition_value = (new CRadioButtonList('value', DOBJECT_STATUS_UP))
@@ -478,7 +486,7 @@ switch ($data['type']) {
 			// Proxy form elements.
 			case CONDITION_TYPE_PROXY:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_PROXY] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_PROXY] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 
@@ -507,40 +515,25 @@ switch ($data['type']) {
 					->addRow(_('Proxy'), $proxy_multiselect);
 				break;
 
-			// Application form elements.
-			case CONDITION_TYPE_APPLICATION:
-				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[$condition_type] as $key => $value) {
-					$operator->addValue($value, $key);
-				}
-				$new_condition_value = (new CTextAreaFlexible('value'))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH);
-
-				$inline_js .= $new_condition_value->getPostJS();
-
-				$form_list
-					->addRow(_('Operator'), $operator)
-					->addRow(_('Value'), $new_condition_value);
-				break;
-
 			// Received value form elements.
 			case CONDITION_TYPE_DVALUE:
-				$operator = new CComboBox('operator', CONDITION_OPERATOR_EQUAL, '',
-					$combobox_options[CONDITION_TYPE_DVALUE]
-				);
-
 				$new_condition_value = (new CTextAreaFlexible('value'))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH);
 
 				$inline_js .= $new_condition_value->getPostJS();
 
 				$form_list
-					->addRow(_('Operator'), $operator)
+					->addRow(new CLabel(_('Operator'), 'label-operator'), (new CSelect('operator'))
+						->setValue(CONDITION_OPERATOR_EQUAL)
+						->setFocusableElementId('label-operator')
+						->addOptions(CSelect::createOptionsFromArray($operators_by_condition[CONDITION_TYPE_DVALUE]))
+					)
 					->addRow(_('Value'), $new_condition_value);
 				break;
 
 			// Service port form elements.
 			case CONDITION_TYPE_DSERVICE_PORT:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_DSERVICE_PORT] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_DSERVICE_PORT] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 
@@ -554,24 +547,25 @@ switch ($data['type']) {
 			// Service type form elements.
 			case CONDITION_TYPE_DSERVICE_TYPE:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_DSERVICE_TYPE] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_DSERVICE_TYPE] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 
 				$discovery_check_types = discovery_check_type2str();
 				order_result($discovery_check_types);
 
-				$new_condition_value = new CComboBox('value', null, null, $discovery_check_types);
-
 				$form_list
 					->addRow(_('Operator'), $operator)
-					->addRow(_('Service type'), $new_condition_value);
+					->addRow(new CLabel(_('Service type'), 'label-condition-service-type'), (new CSelect('value'))
+						->setFocusableElementId('label-condition-service-type')
+						->addOptions(CSelect::createOptionsFromArray($discovery_check_types))
+					);
 				break;
 
 			// Discovery uptime|downtime form elements.
 			case CONDITION_TYPE_DUPTIME:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_MORE_EQUAL))->setModern(true);
-				foreach ($combobox_options[CONDITION_TYPE_DUPTIME] as $key => $value) {
+				foreach ($operators_by_condition[CONDITION_TYPE_DUPTIME] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 				$new_condition_value = (new CNumericBox('value', 600, 15))->setWidth(ZBX_TEXTAREA_NUMERIC_BIG_WIDTH);
@@ -588,7 +582,7 @@ switch ($data['type']) {
 			// Host metadata form elements.
 			case CONDITION_TYPE_HOST_METADATA:
 				$operator = (new CRadioButtonList('operator', CONDITION_OPERATOR_LIKE))->setModern(true);
-				foreach ($combobox_options[$condition_type] as $key => $value) {
+				foreach ($operators_by_condition[$condition_type] as $key => $value) {
 					$operator->addValue($value, $key);
 				}
 				$new_condition_value = (new CTextAreaFlexible('value'))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH);
@@ -604,14 +598,16 @@ switch ($data['type']) {
 			case CONDITION_TYPE_EVENT_TYPE:
 				$operator = (new CRadioButtonList('', CONDITION_OPERATOR_EQUAL))
 					->setModern(true)
-					->addValue($combobox_options[CONDITION_TYPE_EVENT_TYPE][CONDITION_OPERATOR_EQUAL],
+					->addValue($operators_by_condition[CONDITION_TYPE_EVENT_TYPE][CONDITION_OPERATOR_EQUAL],
 						CONDITION_OPERATOR_EQUAL
 					);
-				$new_condition_value = new CComboBox('value', null, null, eventType());
 
 				$form_list
 					->addRow(_('Operator'), [$operator, new CVar('operator', CONDITION_OPERATOR_EQUAL)])
-					->addRow(_('Event type'), $new_condition_value);
+					->addRow(new CLabel(_('Event type'), 'label-condition-event-type'), (new CSelect('value'))
+						->setFocusableElementId('label-condition-event-type')
+						->addOptions(CSelect::createOptionsFromArray(eventType()))
+					);
 				break;
 		}
 		break;
@@ -619,18 +615,22 @@ switch ($data['type']) {
 	case ZBX_POPUP_CONDITION_TYPE_ACTION_OPERATION:
 		require_once dirname(__FILE__).'/../../include/actions.inc.php';
 
-		// Collect all options for combobox.
-		$combobox_options = [];
+		// Collect all options for select.
+		$condition_options = [];
 		foreach ($data['allowed_conditions'] as $type) {
-			$combobox_options[$type] = condition_type2str($type);
+			$condition_options[$type] = condition_type2str($type);
 		}
 
 		// Type select.
-		$opcondition_type_combobox = new CComboBox('condition_type', $condition_type,
-			"reloadPopup(this.form, 'popup.condition.operations');", $combobox_options
+		$form_list->addRow(new CLabel(_('Type'), 'label-condition-type'), (new CSelect('condition_type'))
+			->setFocusableElementId('label-condition-type')
+			->setValue($condition_type)
+			->setId('condition-type')
+			->addOptions(CSelect::createOptionsFromArray($condition_options))
 		);
 
-		$form_list->addRow(_('Type'), $opcondition_type_combobox);
+		$inline_js .= '$(() => $("#condition-type").on("change",'
+			.'(e) => reloadPopup($(e.target).closest("form").get(0), "popup.condition.operations")));';
 
 		// Acknowledge form elements.
 		$operators_options = [];
