@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ $expression_form = (new CForm())
 	->addVar('dstfld1', $data['dstfld1'])
 	->addItem((new CVar('hostid', $data['hostid']))->removeId())
 	->addVar('groupid', $data['groupid'])
-	->addVar('itemid', $data['itemid'])
+	->addVar('function', $data['function'])
 	->addItem((new CInput('submit', 'submit'))
 		->addStyle('display: none;')
 		->removeId()
@@ -65,45 +65,83 @@ if ($data['parent_discoveryid'] !== '') {
 	$popup_options['normal_only'] = '1';
 }
 
-$item = [
-	(new CTextBox('item_description', $data['item_description'], true))
-		->setAriaRequired()
-		->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
-	(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-	(new CButton('select', _('Select')))
-		->addClass(ZBX_STYLE_BTN_GREY)
-		->onClick('return PopUp("popup.generic",'.json_encode($popup_options).', null, this);')
+if ($data['item_required']) {
+	$expression_form->addVar('itemid', $data['itemid']);
+
+	$item = [
+		(new CTextBox('item_description', $data['item_description'], true))
+			->setAriaRequired()
+			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH),
+		(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+		(new CButton('select', _('Select')))
+			->addClass(ZBX_STYLE_BTN_GREY)
+			->onClick('return PopUp("popup.generic",'.json_encode($popup_options).', null, this);')
+	];
+
+	if ($data['parent_discoveryid'] !== '') {
+		$item[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
+		$item[] = (new CButton('select', _('Select prototype')))
+			->addClass(ZBX_STYLE_BTN_GREY)
+			->onClick('return PopUp("popup.generic",'.
+				json_encode([
+					'srctbl' => 'item_prototypes',
+					'srcfld1' => 'itemid',
+					'srcfld2' => 'name',
+					'dstfrm' => $expression_form->getName(),
+					'dstfld1' => 'itemid',
+					'dstfld2' => 'item_description',
+					'parent_discoveryid' => $data['parent_discoveryid']
+				]).', null, this);'
+			)
+			->removeId();
+	}
+
+	$expression_form_list->addRow((new CLabel(_('Item'), 'item_description'))->setAsteriskMark(), $item);
+}
+
+$function_select = (new CSelect('function_select'))
+	->setFocusableElementId('label-function')
+	->setId('function-select')
+	->setValue($data['function_type'].'_'.$data['function']);
+
+$function_types = [
+	ZBX_FUNCTION_TYPE_AGGREGATE => _('Aggregate functions'),
+	ZBX_FUNCTION_TYPE_BITWISE => _('Bitwise functions'),
+	ZBX_FUNCTION_TYPE_DATE_TIME => _('Date and time functions'),
+	ZBX_FUNCTION_TYPE_HISTORY => _('History functions'),
+	ZBX_FUNCTION_TYPE_MATH => _('Mathematical functions'),
+	ZBX_FUNCTION_TYPE_OPERATOR => _('Operator functions'),
+	ZBX_FUNCTION_TYPE_PREDICTION => _('Prediction functions'),
+	ZBX_FUNCTION_TYPE_STRING => _('String functions')
 ];
 
-if ($data['parent_discoveryid'] !== '') {
-	$item[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-	$item[] = (new CButton('select', _('Select prototype')))
-		->addClass(ZBX_STYLE_BTN_GREY)
-		->onClick('return PopUp("popup.generic",'.
-			json_encode([
-				'srctbl' => 'item_prototypes',
-				'srcfld1' => 'itemid',
-				'srcfld2' => 'name',
-				'dstfrm' => $expression_form->getName(),
-				'dstfld1' => 'itemid',
-				'dstfld2' => 'item_description',
-				'parent_discoveryid' => $data['parent_discoveryid']
-			]).', null, this);'
-		)
-		->removeId();
+$functions_by_group = [];
+foreach ($data['functions'] as $id => $function) {
+	foreach ($function['types'] as $type) {
+		$functions_by_group[$function_types[$type]][$type.'_'.$id] = $function['description'];
+	}
+}
+ksort($functions_by_group);
+
+foreach ($functions_by_group as $group_name => $functions) {
+	$function_select->addOptionGroup(
+		(new CSelectOptionGroup($group_name))->addOptions(CSelect::createOptionsFromArray($functions))
+	);
 }
 
-$expression_form_list->addRow((new CLabel(_('Item'), 'item_description'))->setAsteriskMark(), $item);
-
-$function_combo_box = new CComboBox('function', $data['function'], 'reloadPopup(this.form, "popup.triggerexpr")');
-foreach ($data['functions'] as $id => $f) {
-	$function_combo_box->addItem($id, $f['description']);
-}
-$expression_form_list->addRow(_('Function'), $function_combo_box);
+$expression_form_list->addRow(new CLabel(_('Function'), $function_select->getFocusableElementId()), $function_select);
 
 if (array_key_exists('params', $data['functions'][$data['selectedFunction']])) {
 	$paramid = 0;
 
+	// Functions with optional #num and time shift parameters.
+	$count_functions = [
+		'acos', 'ascii', 'asin', 'atan', 'atan2', 'between', 'bitand', 'bitlength', 'bitlshift', 'bitnot', 'bitor',
+		'bitrshift', 'bitxor', 'bytelength', 'cbrt', 'ceil', 'char', 'concat', 'cos', 'cosh', 'cot', 'degrees', 'exp',
+		'expm1', 'floor', 'in', 'insert', 'last', 'left', 'log', 'log10', 'ltrim', 'mid', 'mod', 'power', 'radians',
+		'repeat', 'replace', 'right', 'round', 'rtrim', 'signum', 'sin', 'sinh', 'sqrt', 'tan', 'trim', 'truncate'
+	];
+
 	foreach ($data['functions'][$data['selectedFunction']]['params'] as $param_name => $param_function) {
 		if (array_key_exists($param_name, $data['params'])) {
 			$param_value = $data['params'][$param_name];
@@ -119,16 +157,15 @@ if (array_key_exists('params', $data['functions'][$data['selectedFunction']])) {
 
 			if (in_array($param_name, ['last'])) {
 				if (array_key_exists('M', $param_function)) {
-					if (in_array($data['selectedFunction'], ['last', 'band', 'strlen'])) {
+					if (in_array($data['selectedFunction'], $count_functions)) {
 						$param_type_element = $param_function['M'][PARAM_TYPE_COUNTS];
 						$label = $param_function['C'];
 						$expression_form->addItem((new CVar('paramtype', PARAM_TYPE_COUNTS))->removeId());
 					}
 					else {
-						$param_type_element = new CComboBox('paramtype',
-							$param_value === '' ? PARAM_TYPE_TIME : $data['paramtype'],
-							null, $param_function['M']
-						);
+						$param_type_element = (new CSelect('paramtype'))
+							->setValue($param_value === '' ? PARAM_TYPE_TIME : $data['paramtype'])
+							->addOptions(CSelect::createOptionsFromArray($param_function['M']));
 					}
 				}
 				else {
@@ -139,9 +176,19 @@ if (array_key_exists('params', $data['functions'][$data['selectedFunction']])) {
 			elseif (in_array($param_name, ['shift'])) {
 				$param_type_element = _('Time');
 			}
+			elseif (in_array($param_name, ['period_shift'])) {
+				$param_type_element = _('Period');
+			}
 
 			$param_field = (new CTextBox('params['.$param_name.']', $param_value))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
 
+			if ($param_name === 'period_shift') {
+				$param_field->setAttribute('placeholder', 'now/h');
+			}
+			elseif ($param_name === 'shift') {
+				$param_field->setAttribute('placeholder', 'now-h');
+			}
+
 			$expression_form_list->addRow($label, [
 				$param_field,
 				(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
@@ -164,19 +211,22 @@ else {
 	$expression_form->addVar('paramtype', PARAM_TYPE_TIME);
 }
 
-$expression_form_list->addRow(
-	(new CLabel(_('Result'), 'value'))->setAsteriskMark(), [
-		new CComboBox('operator', $data['operator'], null,
-			array_combine($data['functions'][$data['function']]['operators'],
-				$data['functions'][$data['function']]['operators']
-			)
-		),
-		' ',
-		(new CTextBox('value', $data['value']))
-			->setAriaRequired()
-			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
-	]
-);
+if (array_key_exists('operators', $data['functions'][$data['selectedFunction']])) {
+	$expression_form_list->addRow(
+		(new CLabel(_('Result'), 'value'))->setAsteriskMark(), [
+			(new CSelect('operator'))
+				->setValue($data['operator'])
+				->setFocusableElementId('value')
+				->addOptions(CSelect::createOptionsFromArray(array_combine($data['functions'][$data['function']]['operators'],
+					$data['functions'][$data['function']]['operators']
+				))),
+			' ',
+			(new CTextBox('value', $data['value']))
+				->setAriaRequired()
+				->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+		]
+	);
+}
 
 $expression_form->addItem($expression_form_list);
 
@@ -192,20 +242,7 @@ $output = [
 			'action' => 'return validate_trigger_expression(overlay);'
 		]
 	],
-	'script_inline' =>
-		'jQuery(function($) {'.
-			'$.valHooks.input = {'.
-				'get: function(elem) {'.
-					'return elem.value;'.
-				'},'.
-				'set: function(elem, value) {'.
-					'var tmp = elem.value;'.
-						'elem.value = value;'.
-
-					'"item_description" === elem.id && tmp !== value && reloadPopup(elem.form, "popup.triggerexpr");'.
-				'}'.
-			'};'.
-		'});'
+	'script_inline' => $this->readJsFile('popup.triggerexpr.js.php')
 ];
 
 if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
