@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@ class CApiServiceFactory extends CRegistryFactory {
 		'action' => CAction::class,
 		'alert' => CAlert::class,
 		'apiinfo' => CAPIInfo::class,
-		'application' => CApplication::class,
 		'auditlog' => CAuditLog::class,
 		'authentication' => CAuthentication::class,
 		'autoregistration' => CAutoregistration::class,
@@ -61,15 +60,15 @@ class CApiServiceFactory extends CRegistryFactory {
 		'module' => CModule::class,
 		'problem' => CProblem::class,
 		'proxy' => CProxy::class,
+		'report' => CReport::class,
 		'role' => CRole::class,
 		'service' => CService::class,
-		'screen' => CScreen::class,
-		'screenitem' => CScreenItem::class,
 		'script' => CScript::class,
 		'settings' => CSettings::class,
 		'task' => CTask::class,
 		'template' => CTemplate::class,
 		'templatedashboard' => CTemplateDashboard::class,
+		'token' => CToken::class,
 		'trend' => CTrend::class,
 		'trigger' => CTrigger::class,
 		'triggerprototype' => CTriggerPrototype::class,
