@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -141,7 +141,7 @@ class CHttpTestManager {
 				'follow_redirects', 'retrieve_mode'
 			],
 			'httptestids' => array_column($httptests, 'httptestid'),
-			'editable' => true,
+			'nopermissions' => true,
 			'preservekeys' => true
 		]);
 
