@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -40,7 +40,6 @@ class Manager extends CRegistryFactory {
 		if (!self::$instance) {
 			$class = __CLASS__;
 			self::$instance = new $class([
-				'application' => 'CApplicationManager',
 				'history' => 'CHistoryManager',
 				'httptest' => 'CHttpTestManager'
 			]);
@@ -49,13 +48,6 @@ class Manager extends CRegistryFactory {
 		return self::$instance;
 	}
 
-	/**
-	 * @return CApplicationManager
-	 */
-	public static function Application() {
-		return self::getInstance()->getObject('application');
-	}
-
 	/**
 	 * @return CHistoryManager
 	 */
