@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -1124,13 +1124,6 @@ class CConfigurationExport {
 			'mediatypeids' => $mediatypeids,
 			'preservekeys' => true
 		]);
-
-		foreach ($this->data['mediaTypes'] as &$media_type) {
-			if ($media_type['type'] == MEDIA_TYPE_WEBHOOK) {
-				CArrayHelper::sort($media_type['parameters'], ['name']);
-			}
-		}
-		unset($media_type);
 	}
 
 	/**
