@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,14 +24,26 @@ class CMenuPopupHelper {
 	/**
 	 * Prepare data for dashboard popup menu.
 	 *
-	 * @param string $dashboardid
+	 * @param string|null $dashboardid
+	 * @param bool        $editable
+	 * @param bool        $has_related_reports
+	 * @param bool        $can_edit_dashboards
+	 * @param bool        $can_view_reports
+	 * @param bool        $can_create_reports
+	 *
+	 * @return array
 	 */
-	public static function getDashboard($dashboardid, $editable) {
+	public static function getDashboard(?string $dashboardid, bool $editable, bool $has_related_reports,
+			bool $can_edit_dashboards, bool $can_view_reports, bool $can_create_reports): array {
 		return [
 			'type' => 'dashboard',
 			'data' => [
 				'dashboardid' => $dashboardid,
-				'editable' => $editable
+				'editable' => $editable,
+				'has_related_reports' => $has_related_reports,
+				'can_edit_dashboards' => $can_edit_dashboards,
+				'can_view_reports' => $can_view_reports,
+				'can_create_reports' => $can_create_reports
 			]
 		];
 	}
@@ -99,6 +111,10 @@ class CMenuPopupHelper {
 			]
 		];
 
+		if (array_key_exists('unique_id', $selement)) {
+			$data['data']['unique_id'] = $selement['unique_id'];
+		}
+
 		if ($severity_min != TRIGGER_SEVERITY_NOT_CLASSIFIED) {
 			$data['data']['severity_min'] = $severity_min;
 		}
@@ -109,33 +125,6 @@ class CMenuPopupHelper {
 		return $data;
 	}
 
-	/**
-	 * Prepare data for refresh time menu popup.
-	 *
-	 * @param string $widgetName
-	 * @param string $currentRate
-	 * @param bool   $multiplier   Multiplier or time mode.
-	 * @param array  $params       (optional) URL parameters.
-	 *
-	 * @return array
-	 */
-	public static function getRefresh($widgetName, $currentRate, $multiplier = false, array $params = []) {
-		$data = [
-			'type' => 'refresh',
-			'data' => [
-				'widgetName' => $widgetName,
-				'currentRate' => $currentRate,
-				'multiplier' => $multiplier ? '1' : '0'
-			]
-		];
-
-		if ($params) {
-			$data['data']['params'] = $params;
-		}
-
-		return $data;
-	}
-
 	/**
 	 * Prepare data for Ajax trigger menu popup.
 	 *
@@ -175,30 +164,38 @@ class CMenuPopupHelper {
 	/**
 	 * Prepare data for item popup menu.
 	 *
-	 * @param string $itemid
+	 * @param array  $data
+	 * @param string $data['itemid']   Item ID.
+	 * @param string $data['context']  Additional parameter in URL to identify main section.
 	 *
 	 * @return array
 	 */
-	public static function getItem($itemid) {
+	public static function getItem(array $data): array {
 		return [
 			'type' => 'item',
 			'data' => [
-				'itemid' => $itemid
-			]
+				'itemid' => $data['itemid']
+			],
+			'context' => $data['context']
 		];
 	}
 
 	/**
 	 * Prepare data for item prototype popup menu.
 	 *
-	 * @param string $itemid
+	 * @param array  $data
+	 * @param string $data['itemid']   Item ID.
+	 * @param string $data['context']  Additional parameter in URL to identify main section.
+	 *
+	 * @return array
 	 */
-	public static function getItemPrototype($itemid) {
+	public static function getItemPrototype(array $data): array {
 		return [
 			'type' => 'item_prototype',
 			'data' => [
-				'itemid' => $itemid
-			]
+				'itemid' => $data['itemid']
+			],
+			'context' => $data['context']
 		];
 	}
 }
