@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,10 +25,16 @@ class CButtonQMessage extends CSubmit {
 	public $msg;
 	public $name;
 
-	public function __construct($name, $caption, $msg = null, $vars = null) {
+	/**
+	 * @var string  An URL parameter to be left in URL after redirect.
+	 */
+	private $url_param_exclude;
+
+	public function __construct($name, $caption, $msg = null, $vars = null, $url_param_exclude = '') {
 		$this->vars = null;
 		$this->msg = null;
 		$this->name = $name;
+		$this->url_param_exclude = $url_param_exclude;
 		parent::__construct($name, $caption);
 		$this->setMessage($msg);
 		$this->setVars($vars);
@@ -62,16 +68,21 @@ class CButtonQMessage extends CSubmit {
 		}
 
 		global $page;
+
 		$confirmation = "Confirm('".$this->msg."')";
 
 		if (isset($this->vars)) {
 			$link = $page['file'].'?'.$this->name.'=1'.$this->vars;
-			$action = "redirect('".(new CUrl($link))->getUrl()."', 'post')";
+			$action = "redirect('".(new CUrl($link))->getUrl()."', 'post'".
+				(($this->url_param_exclude !== '') ? ", '".$this->url_param_exclude."'" : "").
+			")";
 		}
 		else {
 			$action = 'true';
 		}
+
 		parent::onClick('if ('.$confirmation.') { return '.$action.'; } else { return false; }');
+
 		return $this;
 	}
 }
