@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -36,9 +36,6 @@ class CUrlFactory {
 			'remove' => ['itemid'],
 			'add' => ['hostid', 'parent_discoveryid']
 		],
-		'discoveryconf.php' => [
-			'remove' => ['druleid']
-		],
 		'graphs.php' => [
 			'remove' => ['graphid'],
 			'add' => ['hostid', 'parent_discoveryid']
@@ -66,13 +63,6 @@ class CUrlFactory {
 		'maintenance.php' => [
 			'remove' => ['maintenanceid']
 		],
-		'screenconf.php' => [
-			'remove' => ['screenid'],
-			'add' => ['templateid']
-		],
-		'slideconf.php' => [
-			'remove' => ['slideshowid']
-		],
 		'sysmaps.php' => [
 			'remove' => ['sysmapid']
 		],
