@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -70,10 +70,22 @@ class CWidgetHelper {
 					->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			)
 			->addItem(
-				(new CScriptTag('$("z-select#type").on("change", () => ZABBIX.Dashboard.reloadWidgetProperties());'))
-					->setOnDocumentReady()
-			);
+				(new CScriptTag('
+					$("z-select#type").on("change", () => ZABBIX.Dashboard.reloadWidgetProperties());
 
+					document
+						.getElementById("widget-dialogue-form")
+						.addEventListener("change", (e) => {
+							const is_trimmable = e.target.matches(
+								\'input[type="text"]:not([data-no-trim="1"]), textarea:not([data-no-trim="1"])\'
+							);
+
+							if (is_trimmable) {
+								e.target.value = e.target.value.trim();
+							}
+						}, {capture: true});
+				'))->setOnDocumentReady()
+			);
 
 		if ($field_rf_rate !== null) {
 			$form_list->addRow(self::getLabel($field_rf_rate), self::getSelect($field_rf_rate));
@@ -176,6 +188,7 @@ class CWidgetHelper {
 			'name' => $field->getName().'[]',
 			'object_name' => 'hosts',
 			'data' => $field->getValue(),
+			'placeholder' => $field->getPlaceholder(),
 			'popup' => [
 				'parameters' => [
 					'srctbl' => 'hosts',
@@ -187,7 +200,6 @@ class CWidgetHelper {
 			'add_post_js' => false
 		]))
 			->setEnabled(!($field->getFlags() & CWidgetField::FLAG_DISABLED))
-			->setAttribute('placeholder', $field->getPlaceholder())
 			->setAriaRequired(self::isAriaRequired($field))
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH);
 	}
