@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ function ipmiAuthTypes($type = null) {
 		IPMI_AUTHTYPE_DEFAULT => _('Default'),
 		IPMI_AUTHTYPE_NONE => _('None'),
 		IPMI_AUTHTYPE_MD2 => _('MD2'),
-		IPMI_AUTHTYPE_MD5 => _('MD5'),
+		IPMI_AUTHTYPE_MD5 => 'MD5',
 		IPMI_AUTHTYPE_STRAIGHT => _('Straight'),
 		IPMI_AUTHTYPE_OEM => _('OEM'),
 		IPMI_AUTHTYPE_RMCP_PLUS => _('RMCP+')
@@ -477,6 +477,34 @@ function hostInterfaceTypeNumToName($type) {
 	return $name;
 }
 
+/**
+ * Returns the host interface as a string of the host's IP address (or DNS name) and port number.
+ *
+ * @param array|null $interface
+ * @param int    $interface['useip']  Interface use IP or DNS. INTERFACE_USE_DNS or INTERFACE_USE_IP.
+ * @param string $interface['ip']     Interface IP.
+ * @param string $interface['dns']    Interface DNS.
+ * @param string $interface['port']   Interface port.
+ *
+ * @return string
+ */
+function getHostInterface(?array $interface): string {
+	if ($interface === null) {
+		return '';
+	}
+
+	if ($interface['useip'] == INTERFACE_USE_IP) {
+		$ip_or_dns = (filter_var($interface['ip'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV6) !== false)
+			? '['.$interface['ip'].']'
+			: $interface['ip'];
+	}
+	else {
+		$ip_or_dns = $interface['dns'];
+	}
+
+	return $ip_or_dns.':'.$interface['port'];
+}
+
 function get_hostgroup_by_groupid($groupid) {
 	$groups = DBfetch(DBselect('SELECT g.* FROM hstgrp g WHERE g.groupid='.zbx_dbstr($groupid)));
 
@@ -533,177 +561,6 @@ function get_host_by_hostid($hostid, $no_error_message = 0) {
 	return false;
 }
 
-/**
- * Get parent templates for each given application.
- *
- * @param array  $applications                     An array of applications.
- * @param string $applications[]['applicationid']  ID of an application.
- * @param array  $applications[]['templateids]     IDs of parent template applications.
- *
- * @return array
- */
-function getApplicationParentTemplates(array $applications) {
-	$parent_applicationids = [];
-	$data = [
-		'links' => [],
-		'templates' => []
-	];
-
-	foreach ($applications as $application) {
-		foreach ($application['templateids'] as $parent_applicationid) {
-			$parent_applicationids[$parent_applicationid] = true;
-			$data['links'][$application['applicationid']][] = ['applicationid' => $parent_applicationid];
-		}
-	}
-
-	if (!$parent_applicationids) {
-		return $data;
-	}
-
-	$all_parent_applicationids = [];
-	$hostids = [];
-
-	while ($parent_applicationids) {
-		$db_applications = API::Application()->get([
-			'output' => ['applicationid', 'hostid', 'templateids'],
-			'applicationids' => array_keys($parent_applicationids)
-		]);
-
-		$all_parent_applicationids += $parent_applicationids;
-		$parent_applicationids = [];
-
-		foreach ($db_applications as $db_application) {
-			$data['templates'][$db_application['hostid']] = [];
-			$hostids[$db_application['applicationid']] = $db_application['hostid'];
-
-			foreach ($db_application['templateids'] as $parent_applicationid) {
-				if (!array_key_exists($parent_applicationid, $all_parent_applicationids)) {
-					$parent_applicationids[$parent_applicationid] = true;
-				}
-			}
-
-			if (!array_key_exists($db_application['applicationid'], $data['links'])) {
-				foreach ($db_application['templateids'] as $parent_applicationid) {
-					$data['links'][$db_application['applicationid']][] = ['applicationid' => $parent_applicationid];
-				}
-			}
-		}
-	}
-
-	foreach ($data['links'] as $applicationid => &$parent_applications) {
-		foreach ($parent_applications as &$parent_application) {
-			$parent_application['hostid'] = array_key_exists($parent_application['applicationid'], $hostids)
-				? $hostids[$parent_application['applicationid']]
-				: 0;
-		}
-		unset($parent_application);
-	}
-	unset($parent_applications);
-
-	$db_templates = $data['templates']
-		? API::Template()->get([
-			'output' => ['name'],
-			'templateids' => array_keys($data['templates']),
-			'preservekeys' => true
-		])
-		: [];
-
-	$rw_templates = $db_templates
-		? API::Template()->get([
-			'output' => [],
-			'templateids' => array_keys($db_templates),
-			'editable' => true,
-			'preservekeys' => true
-		])
-		: [];
-
-	$data['templates'][0] = [];
-
-	foreach ($data['templates'] as $hostid => &$template) {
-		$template = array_key_exists($hostid, $db_templates)
-			? [
-				'hostid' => $hostid,
-				'name' => $db_templates[$hostid]['name'],
-				'permission' => array_key_exists($hostid, $rw_templates) ? PERM_READ_WRITE : PERM_READ
-			]
-			: [
-				'hostid' => $hostid,
-				'name' => _('Inaccessible template'),
-				'permission' => PERM_DENY
-			];
-	}
-	unset($template);
-
-	return $data;
-}
-
-/**
- * Auxiliary function for makeApplicationTemplatePrefix().
- *
- * @param string $applicationid
- * @param array  $parent_templates
- *
- * @return array
- */
-function getTopLevelTemplates($applicationid, array $parent_templates) {
-	$templates = [];
-
-	foreach ($parent_templates['links'][$applicationid] as $parent_application) {
-		if (!array_key_exists($parent_application['applicationid'], $parent_templates['links'])) {
-			$templates[] = $parent_templates['templates'][$parent_application['hostid']];
-		}
-		else {
-			$templates = array_merge($templates,
-				getTopLevelTemplates($parent_application['applicationid'], $parent_templates)
-			);
-		}
-	}
-
-	return $templates;
-}
-
-/**
- * Returns a template prefix for selected application.
- *
- * @param string $applicationid
- * @param array  $parent_templates  The list of the templates, prepared by getApplicationParentTemplates() function.
- * @param bool   $provide_links     If this parameter is false, prefix will not contain links.
- *
- * @return array|null
- */
-function makeApplicationTemplatePrefix($applicationid, array $parent_templates, bool $provide_links) {
-	if (!array_key_exists($applicationid, $parent_templates['links'])) {
-		return null;
-	}
-
-	$templates = getTopLevelTemplates($applicationid, $parent_templates);
-	CArrayHelper::sort($templates, ['name']);
-
-	$list = [];
-
-	foreach ($templates as $template) {
-		if ($provide_links && $template['permission'] == PERM_READ_WRITE) {
-			$name = (new CLink(CHtml::encode($template['name']),
-				(new CUrl('zabbix.php'))
-					->setArgument('action', 'application.list')
-					->setArgument('filter_set', '1')
-					->setArgument('filter_hostids', [$template['hostid']])
-			))->addClass(ZBX_STYLE_LINK_ALT);
-		}
-		else {
-			$name = new CSpan(CHtml::encode($template['name']));
-		}
-
-		$list[] = $name->addClass(ZBX_STYLE_GREY);
-		$list[] = ', ';
-	}
-
-	array_pop($list);
-	$list[] = NAME_DELIMITER;
-
-	return $list;
-}
-
 /**
  * Get parent templates for each given host prototype.
  *
@@ -834,6 +691,7 @@ function makeHostPrototypeTemplatePrefix($host_prototypeid, array $parent_templa
 		$name = (new CLink(CHtml::encode($template['name']),
 			(new CUrl('host_prototypes.php'))
 				->setArgument('parent_discoveryid', $parent_templates['links'][$host_prototypeid]['lld_ruleid'])
+				->setArgument('context', 'template')
 		))->addClass(ZBX_STYLE_LINK_ALT);
 	}
 	else {
@@ -864,6 +722,7 @@ function makeHostPrototypeTemplatesHtml($host_prototypeid, array $parent_templat
 					->setArgument('form', 'update')
 					->setArgument('parent_discoveryid', $parent_templates['links'][$host_prototypeid]['lld_ruleid'])
 					->setArgument('hostid', $parent_templates['links'][$host_prototypeid]['hostid'])
+					->setArgument('context', 'template')
 			);
 		}
 		else {
