@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,21 +31,24 @@ $widget = (new CWidget())
 				(new CUrl('disc_prototypes.php'))
 					->setArgument('form', 'create')
 					->setArgument('parent_discoveryid', $data['parent_discoveryid'])
+					->setArgument('context', $data['context'])
 					->getUrl()
 			))
 		))->setAttribute('aria-label', _('Content controls'))
 	)
 	->setNavigation(getHostNavigation('items', $data['hostid'], $data['parent_discoveryid']));
 
-// create form
-$itemForm = (new CForm())
-	->setName('items')
-	->addVar('parent_discoveryid', $data['parent_discoveryid']);
-
 $url = (new CUrl('disc_prototypes.php'))
 	->setArgument('parent_discoveryid', $data['parent_discoveryid'])
+	->setArgument('context', $data['context'])
 	->getUrl();
 
+// create form
+$itemForm = (new CForm('post', $url))
+	->setName('items')
+	->addVar('parent_discoveryid', $data['parent_discoveryid'])
+	->addVar('context', $data['context']);
+
 // create table
 $itemTable = (new CTableInfo())
 	->setHeader([
@@ -59,9 +62,9 @@ $itemTable = (new CTableInfo())
 		make_sorting_header(_('History'), 'history', $data['sort'], $data['sortorder'], $url),
 		make_sorting_header(_('Trends'), 'trends', $data['sort'], $data['sortorder'], $url),
 		make_sorting_header(_('Type'), 'type', $data['sort'], $data['sortorder'], $url),
-		_('Applications'),
 		make_sorting_header(_('Create enabled'), 'status', $data['sort'], $data['sortorder'], $url),
-		make_sorting_header(_('Discover'), 'discover', $data['sort'], $data['sortorder'], $url)
+		make_sorting_header(_('Discover'), 'discover', $data['sort'], $data['sortorder'], $url),
+		_('Tags')
 	]);
 
 $update_interval_parser = new CUpdateIntervalParser(['usermacros' => true, 'lldmacros' => true]);
@@ -78,15 +81,19 @@ foreach ($data['items'] as $item) {
 		}
 		else {
 			$link = ($item['master_item']['source'] === 'itemprototypes')
-				? (new CUrl('disc_prototypes.php'))->setArgument('parent_discoveryid', $data['parent_discoveryid'])
+				? (new CUrl('disc_prototypes.php'))
+					->setArgument('parent_discoveryid', $data['parent_discoveryid'])
+					->setArgument('context', $data['context'])
 				: (new CUrl('items.php'))
 					->setArgument('filter_set', '1')
-					->setArgument('filter_hostids', [$item['hostid']]);
+					->setArgument('filter_hostids', [$item['hostid']])
+					->setArgument('context', $data['context']);
 
 			$description[] = (new CLink(CHtml::encode($item['master_item']['name_expanded']),
 				$link
 					->setArgument('form', 'update')
 					->setArgument('itemid', $item['master_item']['itemid'])
+					->setArgument('context', $data['context'])
 					->getUrl()
 			))
 				->addClass(ZBX_STYLE_LINK_ALT)
@@ -102,6 +109,7 @@ foreach ($data['items'] as $item) {
 			->setArgument('form', 'update')
 			->setArgument('parent_discoveryid', $data['parent_discoveryid'])
 			->setArgument('itemid', $item['itemid'])
+			->setArgument('context', $data['context'])
 			->getUrl()
 	);
 
@@ -114,25 +122,13 @@ foreach ($data['items'] as $item) {
 				? 'itemprototype.massenable'
 				: 'itemprototype.massdisable'
 			)
+			->setArgument('context', $data['context'])
 			->getUrl()
 	))
 		->addClass(ZBX_STYLE_LINK_ACTION)
 		->addClass(itemIndicatorStyle($item['status']))
 		->addSID();
 
-	if (!empty($item['applications'])) {
-		order_result($item['applications'], 'name');
-
-		$applications = zbx_objectValues($item['applications'], 'name');
-		$applications = implode(', ', $applications);
-		if (empty($applications)) {
-			$applications = '';
-		}
-	}
-	else {
-		$applications = '';
-	}
-
 	if (in_array($item['value_type'], [ITEM_VALUE_TYPE_STR, ITEM_VALUE_TYPE_LOG, ITEM_VALUE_TYPE_TEXT])) {
 		$item['trends'] = '';
 	}
@@ -147,7 +143,7 @@ foreach ($data['items'] as $item) {
 		$item['delay'] = $update_interval_parser->getDelay();
 	}
 
-	$item_menu = CMenuPopupHelper::getItemPrototype($item['itemid'], $data['parent_discoveryid']);
+	$item_menu = CMenuPopupHelper::getItemPrototype(['itemid' => $item['itemid'], 'context' => $data['context']]);
 
 	$wizard = (new CSpan(
 		(new CButton(null))->addClass(ZBX_STYLE_ICON_WZRD_ACTION)->setMenuPopup($item_menu)
@@ -158,10 +154,11 @@ foreach ($data['items'] as $item) {
 			(new CUrl('disc_prototypes.php'))
 				->setArgument('group_itemid[]', $item['itemid'])
 				->setArgument('parent_discoveryid', $data['parent_discoveryid'])
-				->setArgument('visible[discover]', '1')
-				->setArgument('massupdate', 'discover')
-				->setArgument('discover', $nodiscover ? ZBX_PROTOTYPE_DISCOVER : ZBX_PROTOTYPE_NO_DISCOVER)
-				->setArgumentSID()
+				->setArgument('action', $nodiscover
+					? 'itemprototype.massdiscover.enable'
+					: 'itemprototype.massdiscover.disable'
+				)
+				->setArgument('context', $data['context'])
 				->getUrl()
 		))
 			->addSID()
@@ -177,9 +174,9 @@ foreach ($data['items'] as $item) {
 		$item['history'],
 		$item['trends'],
 		item_type2str($item['type']),
-		$applications,
 		$status,
-		$discover
+		$discover,
+		$data['tags'][$item['itemid']]
 	]);
 }
 
@@ -195,7 +192,12 @@ $itemForm->addItem([
 			'itemprototype.massdisable' => ['name' => _('Create disabled'),
 				'confirm' => _('Create items from selected prototypes as disabled?')
 			],
-			'itemprototype.massupdateform' => ['name' => _('Mass update')],
+			'popup.massupdate.itemprototype' => [
+				'content' => (new CButton('', _('Mass update')))
+					->onClick("return openMassupdatePopup(this, 'popup.massupdate.itemprototype');")
+					->addClass(ZBX_STYLE_BTN_ALT)
+					->removeAttribute('id')
+			],
 			'itemprototype.massdelete' => ['name' => _('Delete'),
 				'confirm' => _('Delete selected item prototypes?')
 			]
