@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -53,13 +53,21 @@ include dirname(__FILE__).'/configuration.host.discovery.edit.overr.js.php';
 				->addClass('macro')
 				->setAttribute('placeholder', '{#MACRO}')
 				->setAttribute('data-formulaid', '#{formulaId}'),
-			(new CComboBox('conditions[#{rowNum}][operator]', CONDITION_OPERATOR_REGEXP, null, [
-				CONDITION_OPERATOR_REGEXP => _('matches'),
-				CONDITION_OPERATOR_NOT_REGEXP => _('does not match')
-			]))->addClass('operator'),
-			(new CTextBox('conditions[#{rowNum}][value]', '', false, 255))
-				->setWidth(ZBX_TEXTAREA_MACRO_VALUE_WIDTH)
-				->setAttribute('placeholder', _('regular expression')),
+			(new CSelect('conditions[#{rowNum}][operator]'))
+				->setValue(CONDITION_OPERATOR_REGEXP)
+				->addClass('js-operator')
+				->addOptions(CSelect::createOptionsFromArray([
+					CONDITION_OPERATOR_REGEXP => _('matches'),
+					CONDITION_OPERATOR_NOT_REGEXP => _('does not match'),
+					CONDITION_OPERATOR_EXISTS => _('exists'),
+					CONDITION_OPERATOR_NOT_EXISTS => _('does not exist')
+				])),
+			(new CDiv(
+				(new CTextBox('conditions[#{rowNum}][value]', '', false, 255))
+					->addClass('js-value')
+					->setWidth(ZBX_TEXTAREA_MACRO_VALUE_WIDTH)
+					->setAttribute('placeholder', _('regular expression'))
+			))->setWidth(ZBX_TEXTAREA_MACRO_VALUE_WIDTH),
 			(new CCol(
 				(new CButton('conditions_#{rowNum}_remove', _('Remove')))
 					->addClass(ZBX_STYLE_BTN_LINK)
@@ -141,6 +149,11 @@ include dirname(__FILE__).'/configuration.host.discovery.edit.overr.js.php';
 					// Change value attribute to trigger MutationObserver event for tab indicator.
 					$(this).attr('value', $(this).val());
 				})
+				.on('afteradd.dynamicRows', (event) => {
+					[...event.currentTarget.querySelectorAll('.js-operator')]
+						.pop()
+						.addEventListener('change', toggleConditionValue);
+				})
 				.ready(function() {
 					$('#conditionRow').toggle($('.form_row', $('#conditions')).length > 1);
 				});
@@ -178,4 +191,22 @@ include dirname(__FILE__).'/configuration.host.discovery.edit.overr.js.php';
 				});
 		});
 	})(jQuery);
+
+	const toggleConditionValue = (event) => {
+		const value = event.currentTarget.closest('.form_row').querySelector('.js-value');
+		const show_value = (event.currentTarget.value == <?= CONDITION_OPERATOR_REGEXP ?>
+				|| event.currentTarget.value == <?= CONDITION_OPERATOR_NOT_REGEXP ?>);
+
+		value.classList.toggle('<?= ZBX_STYLE_DISPLAY_NONE ?>', !show_value);
+
+		if (!show_value) {
+			value.value = '';
+		}
+	};
+
+	document.addEventListener('DOMContentLoaded', () => {
+		[...document.getElementById('conditions').querySelectorAll('.js-operator')].map((elem) => {
+			elem.addEventListener('change', toggleConditionValue);
+		});
+	});
 </script>
