@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -107,7 +107,7 @@ function removeObjectById(id) {
  * Converts all HTML symbols into HTML entities.
  */
 jQuery.escapeHtml = function(html) {
-	return jQuery('<div />').text(html).html();
+	return jQuery('<div>').text(html).html();
 }
 
 function validateNumericBox(obj, allowempty, allownegative) {
@@ -850,7 +850,7 @@ function downloadSvgImage(svg, file_name) {
 	image.onload = function() {
 		context2d.drawImage(image, 0, 0);
 		a.href = canvas.toDataURL('image/png');
-		a.rel = 'noopener';
+		a.rel = 'noopener' + (ZBX_NOREFERER ? ' noreferrer' : '');
 		a.download = file_name;
 		a.target = '_blank';
 		a.click();
@@ -881,7 +881,7 @@ function downloadPngImage(img, file_name) {
 	var a = document.createElement('a');
 
 	a.href = img.src;
-	a.rel = 'noopener';
+	a.rel = 'noopener' + (ZBX_NOREFERER ? ' noreferrer' : '');
 	a.download = file_name;
 	a.target = '_blank';
 	a.click();
