@@ -1,6 +1,6 @@
 /*
  ** Zabbix
- ** Copyright (C) 2001-2020 Zabbix SIA
+ ** Copyright (C) 2001-2022 Zabbix SIA
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -88,27 +88,6 @@ jQuery(function($) {
 		});
 	}
 
-	/**
-	 * Change combobox color according selected option.
-	 */
-	$('select').each(function() {
-		var comboBox = $(this),
-			changeClass = function(obj) {
-				if (obj.find('option.red:selected').length > 0) {
-					obj.addClass('red');
-				}
-				else {
-					obj.removeClass('red');
-				}
-			};
-
-		comboBox.change(function() {
-			changeClass($(this));
-		});
-
-		changeClass(comboBox);
-	});
-
 	function uncheckedHandler($checkbox) {
 		var $hidden = $checkbox.prev('input[type=hidden][name="' + $checkbox.prop('name') + '"]');
 
@@ -159,10 +138,6 @@ jQuery(function($) {
 				sections = getMenuPopupMapElementImage(data);
 				break;
 
-			case 'refresh':
-				sections = getMenuPopupRefresh(data, $obj);
-				break;
-
 			case 'trigger':
 				sections = getMenuPopupTrigger(data, $obj);
 				break;
@@ -192,7 +167,7 @@ jQuery(function($) {
 				break;
 
 			case 'widget_actions':
-				sections = getMenuPopupWidgetActions(data, $obj);
+				sections = getMenuPopupWidgetActions(data);
 				break;
 
 			default:
@@ -236,6 +211,7 @@ jQuery(function($) {
 			case 'dashboard':
 			case 'dropdown':
 			case 'submenu':
+			case 'widget_actions':
 				return false;
 
 			default:
@@ -269,9 +245,22 @@ jQuery(function($) {
 			default:
 				// Should match the default algorithm used in $.menuPopup().
 				return {
-					of: (event.type === 'click' && event.originalEvent.detail) ? event : event.target,
+					of: (['click', 'mouseup', 'mousedown'].includes(event.type) && event.originalEvent.detail)
+						? event
+						: event.target,
 					my: 'left top',
-					at: 'left bottom'
+					at: 'left bottom',
+					using: (pos, data) => {
+						let max_left = data.horizontal === 'left'
+							? document.querySelector('.wrapper').clientWidth
+							: document.querySelector('.wrapper').clientWidth - data.element.width;
+
+						pos.top = Math.max(0, pos.top);
+						pos.left = Math.max(0, Math.min(max_left, pos.left));
+
+						data.element.element[0].style.top = `${pos.top}px`;
+						data.element.element[0].style.left = `${pos.left}px`;
+					}
 				};
 		}
 	}
@@ -325,7 +314,7 @@ jQuery(function($) {
 
 			xhr.done(function(resp) {
 				overlayPreloaderDestroy($preloader.prop('id'));
-				showMenuPopup($obj, resp.data, event, options);
+				showMenuPopup($obj, jQuery.extend({context: data.context}, resp.data), event, options);
 			});
 
 			$(document)
@@ -358,7 +347,8 @@ jQuery(function($) {
 				if (typeof data.values[i].id !== 'undefined') {
 					var item = {
 						'id': data.values[i].id,
-						'name': data.values[i].name
+						'name': data.values[i].name,
+						'query': data.values[i].query
 					};
 
 					if (typeof data.values[i].prefix !== 'undefined') {
@@ -370,10 +360,9 @@ jQuery(function($) {
 
 			$('#' + data.parentId).multiSelect('addData', items);
 		}
-		else if (!$('[name="' + data.parentId + '"]').hasClass('simple-textbox')
-				&& typeof addPopupValues !== 'undefined') {
+		else if (typeof window.addPopupValues !== 'undefined') {
 			// execute function if they exist
-			addPopupValues(data);
+			window.addPopupValues(data);
 		}
 		else {
 			$('#' + data.parentId).val(data.values[0].name);
@@ -383,10 +372,10 @@ jQuery(function($) {
 	// redirect buttons
 	$('button[data-url]').click(function() {
 		var button = $(this);
-		var confirmation = button.data('confirmation');
+		var confirmation = button.attr('data-confirmation');
 
 		if (typeof confirmation === 'undefined' || (typeof confirmation !== 'undefined' && confirm(confirmation))) {
-			window.location = button.data('url');
+			window.location = button.attr('data-url');
 		}
 	});
 
