@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -1115,6 +1115,7 @@ jQuery(function($) {
 							? document.querySelector('.wrapper').clientWidth
 							: document.querySelector('.wrapper').clientWidth - data.element.width;
 
+						pos.top = Math.max(0, pos.top);
 						pos.left = Math.max(0, Math.min(max_left, pos.left));
 
 						data.element.element[0].style.top = `${pos.top}px`;
@@ -1425,18 +1426,22 @@ jQuery(function($) {
 			});
 		}
 
+		link.addClass('menu-popup-item');
+
 		if (options.disabled) {
-			link.addClass('menu-popup-item-disabled');
+			link.addClass('disabled');
 		}
 		else {
-			link.addClass('menu-popup-item');
-
 			if (typeof options.url !== 'undefined') {
 				link.attr('href', options.url);
 
 				if ('target' in options) {
 					link.attr('target', options.target);
 				}
+
+				if ('rel' in options) {
+					link.attr('rel', options.rel);
+				}
 			}
 
 			if (typeof options.clickCallback !== 'undefined') {
