@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ require_once dirname(__FILE__).'/include/items.inc.php';
 $page['title'] = _('Overview');
 $page['file'] = 'overview.php';
 $page['type'] = detect_page_type(PAGE_TYPE_HTML);
-$page['scripts'] = ['layout.mode.js', 'multiselect.js', 'monitoring.overview.js'];
+$page['scripts'] = ['layout.mode.js', 'multiselect.js', 'monitoring.overview.js', 'class.tagfilteritem.js'];
 $page['web_layout_mode'] = CViewHelper::loadLayoutMode();
 
 define('ZBX_PAGE_DO_REFRESH', 1);
@@ -45,6 +45,8 @@ $fields = [
 	'filter_set' =>			[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
 	'filter_groupids' =>	[T_ZBX_INT, O_OPT, null,	DB_ID,		null],
 	'filter_hostids' =>		[T_ZBX_INT, O_OPT, null,	DB_ID,		null],
+	'filter_evaltype' =>	[T_ZBX_INT, O_OPT, null,	IN([TAG_EVAL_TYPE_AND_OR, TAG_EVAL_TYPE_OR]), null],
+	'filter_tags' =>		[T_ZBX_STR, O_OPT, null,	null,		null],
 	'show_triggers' =>		[T_ZBX_INT, O_OPT, null,	null,		null],
 	'ack_status' =>			[T_ZBX_INT, O_OPT, P_SYS,	null,		null],
 	'show_severity' =>		[T_ZBX_INT, O_OPT, P_SYS,	null,		null],
@@ -52,7 +54,6 @@ $fields = [
 	'status_change_days' =>	[T_ZBX_INT, O_OPT, null,	BETWEEN(1, DAY_IN_YEAR * 2), null],
 	'status_change' =>		[T_ZBX_INT, O_OPT, null,	null,		null],
 	'txt_select' =>			[T_ZBX_STR, O_OPT, null,	null,		null],
-	'application' =>		[T_ZBX_STR, O_OPT, null,	null,		null],
 	'inventory' =>			[T_ZBX_STR, O_OPT, null,	null,		null]
 ];
 check_fields($fields);
@@ -72,7 +73,6 @@ if (hasRequest('filter_set')) {
 	CProfile::update('web.overview.filter.status_change_days', getRequest('status_change_days', 14),
 		PROFILE_TYPE_INT
 	);
-	CProfile::update('web.overview.filter.application', getRequest('application'), PROFILE_TYPE_STR);
 
 	// ack status
 	CProfile::update('web.overview.filter.ack_status', getRequest('ack_status', 0), PROFILE_TYPE_INT);
@@ -92,6 +92,24 @@ if (hasRequest('filter_set')) {
 	CProfile::updateArray('web.overview.filter.inventory.value', $inventoryValues, PROFILE_TYPE_STR);
 	CProfile::updateArray('web.overview.filter.groupids', getRequest('filter_groupids', []), PROFILE_TYPE_ID);
 	CProfile::updateArray('web.overview.filter.hostids', getRequest('filter_hostids', []), PROFILE_TYPE_ID);
+
+	$filter_tags = ['tags' => [], 'values' => [], 'operators' => []];
+	foreach (getRequest('filter_tags', []) as $filter_tag) {
+		if ($filter_tag['tag'] === '' && $filter_tag['value'] === '') {
+			continue;
+		}
+
+		$filter_tags['tags'][] = $filter_tag['tag'];
+		$filter_tags['values'][] = $filter_tag['value'];
+		$filter_tags['operators'][] = $filter_tag['operator'];
+	}
+
+	CProfile::update('web.overview.filter.evaltype', getRequest('filter_evaltype', TAG_EVAL_TYPE_AND_OR),
+		PROFILE_TYPE_INT
+	);
+	CProfile::updateArray('web.overview.filter.tags.tag', $filter_tags['tags'], PROFILE_TYPE_STR);
+	CProfile::updateArray('web.overview.filter.tags.value', $filter_tags['values'], PROFILE_TYPE_STR);
+	CProfile::updateArray('web.overview.filter.tags.operator', $filter_tags['operators'], PROFILE_TYPE_INT);
 }
 elseif (hasRequest('filter_rst')) {
 	DBStart();
@@ -102,19 +120,18 @@ elseif (hasRequest('filter_rst')) {
 	CProfile::delete('web.overview.filter.txt_select');
 	CProfile::delete('web.overview.filter.status_change');
 	CProfile::delete('web.overview.filter.status_change_days');
-	CProfile::delete('web.overview.filter.application');
 	CProfile::deleteIdx('web.overview.filter.inventory.field');
 	CProfile::deleteIdx('web.overview.filter.inventory.value');
 	CProfile::deleteIdx('web.overview.filter.groupids');
 	CProfile::deleteIdx('web.overview.filter.hostids');
+	CProfile::delete('web.overview.filter.evaltype');
+	CProfile::deleteIdx('web.overview.filter.tags.tag');
+	CProfile::deleteIdx('web.overview.filter.tags.value');
+	CProfile::deleteIdx('web.overview.filter.tags.operator');
 	DBend();
 }
 
-// overview type
-if (hasRequest('type')) {
-	CProfile::update('web.overview.type', getRequest('type'), PROFILE_TYPE_INT);
-}
-$type = CProfile::get('web.overview.type', SHOW_TRIGGERS);
+$type = getRequest('type', SHOW_TRIGGERS);
 
 // overview style
 if (hasRequest('view_style')) {
@@ -134,81 +151,94 @@ $data = [
 	'dependencies' => [],
 	'triggers_by_name' => [],
 	'hosts_by_name' => [],
-	'exceeded_limit' => false
+	'exceeded_limit' => false,
+	'filter' => [
+		'hostids' => CProfile::getArray('web.overview.filter.hostids', []),
+		'groupids' => CProfile::getArray('web.overview.filter.groupids', []),
+		'show_suppressed' => CProfile::get('web.overview.filter.show_suppressed', ZBX_PROBLEM_SUPPRESSED_FALSE),
+		'evaltype' => CProfile::get('web.overview.filter.evaltype', TAG_EVAL_TYPE_AND_OR),
+		'tags' => []
+	]
 ];
 
+foreach (CProfile::getArray('web.overview.filter.tags.tag', []) as $i => $tag) {
+	$data['filter']['tags'][] = [
+		'tag' => $tag,
+		'value' => CProfile::get('web.overview.filter.tags.value', null, $i),
+		'operator' => CProfile::get('web.overview.filter.tags.operator', null, $i)
+	];
+}
+
 // fetch trigger data
 if ($type == SHOW_TRIGGERS) {
 	// filter data
-	$filter = [
+	$data['filter'] += [
 		'showTriggers' => CProfile::get('web.overview.filter.show_triggers', TRIGGERS_OPTION_RECENT_PROBLEM),
 		'ackStatus' => CProfile::get('web.overview.filter.ack_status', 0),
 		'showSeverity' => CProfile::get('web.overview.filter.show_severity', TRIGGER_SEVERITY_NOT_CLASSIFIED),
 		'statusChange' => CProfile::get('web.overview.filter.status_change', 0),
 		'statusChangeDays' => CProfile::get('web.overview.filter.status_change_days', 14),
 		'txtSelect' => CProfile::get('web.overview.filter.txt_select', ''),
-		'application' => CProfile::get('web.overview.filter.application', ''),
-		'show_suppressed' => CProfile::get('web.overview.filter.show_suppressed', ZBX_PROBLEM_SUPPRESSED_FALSE),
-		'groupids' => CProfile::getArray('web.overview.filter.groupids', []),
-		'hostids' => CProfile::getArray('web.overview.filter.hostids', []),
 		'inventory' => []
 	];
 
 	foreach (CProfile::getArray('web.overview.filter.inventory.field', []) as $i => $field) {
-		$filter['inventory'][] = [
+		$data['filter']['inventory'][] = [
 			'field' => $field,
 			'value' => CProfile::get('web.overview.filter.inventory.value', null, $i)
 		];
 	}
 
 	$trigger_options = [
-		'search' => ($filter['txtSelect'] !== '') ? ['description' => $filter['txtSelect']] : null,
-		'only_true' => ($filter['showTriggers'] == TRIGGERS_OPTION_RECENT_PROBLEM) ? true : null,
+		'search' => ($data['filter']['txtSelect'] !== '') ? ['description' => $data['filter']['txtSelect']] : null,
+		'only_true' => ($data['filter']['showTriggers'] == TRIGGERS_OPTION_RECENT_PROBLEM) ? true : null,
 		'filter' => [
-			'value' => ($filter['showTriggers'] == TRIGGERS_OPTION_IN_PROBLEM) ? TRIGGER_VALUE_TRUE : null
+			'value' => ($data['filter']['showTriggers'] == TRIGGERS_OPTION_IN_PROBLEM) ? TRIGGER_VALUE_TRUE : null
 		],
-		'skipDependent' => ($filter['showTriggers'] == TRIGGERS_OPTION_ALL) ? null : true
+		'skipDependent' => ($data['filter']['showTriggers'] == TRIGGERS_OPTION_ALL) ? null : true
 	];
 
 	$problem_options = [
-		'show_recent' => ($filter['showTriggers'] == TRIGGERS_OPTION_RECENT_PROBLEM) ? true : null,
-		'show_suppressed' => $filter['show_suppressed'],
-		'acknowledged' => ($filter['ackStatus'] == EXTACK_OPTION_UNACK) ? false : null,
-		'min_severity' => $filter['showSeverity'],
-		'time_from' => $filter['statusChange'] ? (time() - $filter['statusChangeDays'] * SEC_PER_DAY) : null
+		'tags' => $data['filter']['tags'] ? $data['filter']['tags'] : null,
+		'evaltype' => $data['filter']['evaltype'] ? $data['filter']['evaltype'] : TAG_EVAL_TYPE_AND_OR,
+		'show_recent' => ($data['filter']['showTriggers'] == TRIGGERS_OPTION_RECENT_PROBLEM) ? true : null,
+		'show_suppressed' => $data['filter']['show_suppressed'],
+		'acknowledged' => ($data['filter']['ackStatus'] == EXTACK_OPTION_UNACK) ? false : null,
+		'min_severity' => $data['filter']['showSeverity'],
+		'time_from' => $data['filter']['statusChange'] ? (time() - $data['filter']['statusChangeDays'] * SEC_PER_DAY) : null
 	];
 
-	$filter['groups'] = $filter['groupids']
+	$data['filter']['groups'] = $data['filter']['groupids']
 		? CArrayHelper::renameObjectsKeys(API::HostGroup()->get([
 			'output' => ['groupid', 'name'],
-			'groupids' => $filter['groupids'],
+			'groupids' => $data['filter']['groupids'],
 			'preservekeys' => true
 		]), ['groupid' => 'id'])
 		: [];
 
-	$groupids = $filter['groups'] ? getSubGroups(array_keys($filter['groups'])) : [];
+	$groupids = $data['filter']['groups'] ? getSubGroups(array_keys($data['filter']['groups'])) : [];
 
-	$filter['hosts'] = $filter['hostids']
+	$data['filter']['hosts'] = $data['filter']['hostids']
 		? CArrayHelper::renameObjectsKeys(API::Host()->get([
 			'output' => ['hostid', 'name'],
-			'hostids' => $filter['hostids'],
+			'hostids' => $data['filter']['hostids'],
 			'monitored_hosts' => true,
 			'with_monitored_triggers' => true,
 			'preservekeys' => true
 		]), ['hostid' => 'id'])
 		: [];
 
-	unset($filter['groupids'], $filter['hostids']);
+	unset($data['filter']['groupids'], $data['filter']['hostids']);
 
 	$host_options = [];
-	if ($filter['inventory']) {
+	if ($data['filter']['inventory']) {
 		$host_options['searchInventory'] = [];
-		foreach ($filter['inventory'] as $field) {
+		foreach ($data['filter']['inventory'] as $field) {
 			$host_options['searchInventory'][$field['field']][] = $field['value'];
 		}
 	}
-	if ($filter['hosts']) {
-		$host_options['hostids'] = array_keys($filter['hosts']);
+	if ($data['filter']['hosts']) {
+		$host_options['hostids'] = array_keys($data['filter']['hosts']);
 	}
 
 	$data['allowed'] = [
@@ -220,26 +250,25 @@ if ($type == SHOW_TRIGGERS) {
 
 	[$data['db_hosts'], $data['db_triggers'], $data['dependencies'], $data['triggers_by_name'], $data['hosts_by_name'],
 		$data['exceeded_limit']
-	] = getTriggersOverviewData($groupids, $filter['application'], $host_options, $trigger_options, $problem_options);
-
-	$data['filter'] = $filter;
+	] = getTriggersOverviewData($groupids, $host_options, $trigger_options, $problem_options);
 
 	$data['config'] = [
 		'blink_period' => CSettingsHelper::get(CSettingsHelper::BLINK_PERIOD)
 	];
 
+	if (!$data['filter']['tags']) {
+		$data['filter']['tags'] = [[
+			'tag' => '',
+			'value' => '',
+			'operator' => TAG_OPERATOR_LIKE
+		]];
+	}
+
 	// Render view.
 	echo (new CView('monitoring.overview.triggers', $data))->getOutput();
 }
 // Fetch item data.
 else {
-	$data['filter'] = [
-		'application' => CProfile::get('web.overview.filter.application', ''),
-		'hostids' => CProfile::getArray('web.overview.filter.hostids', []),
-		'groupids' => CProfile::getArray('web.overview.filter.groupids', []),
-		'show_suppressed' => CProfile::get('web.overview.filter.show_suppressed', ZBX_PROBLEM_SUPPRESSED_FALSE)
-	];
-
 	$data['filter']['groups'] = $data['filter']['groupids']
 		? CArrayHelper::renameObjectsKeys(API::HostGroup()->get([
 			'output' => ['groupid', 'name'],
@@ -263,6 +292,14 @@ else {
 
 	[$data['items'], $data['hosts'], $data['has_hidden_data']] = getDataOverview($groupids, $hostids, $data['filter']);
 
+	if (!$data['filter']['tags']) {
+		$data['filter']['tags'] = [[
+			'tag' => '',
+			'value' => '',
+			'operator' => TAG_OPERATOR_LIKE
+		]];
+	}
+
 	// Render view.
 	echo (new CView('monitoring.overview.items', $data))->getOutput();
 }
