@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -273,7 +273,7 @@ if (hasRequest('form')) {
 				'serviceids' => zbx_objectValues($service['dependencies'], 'servicedownid'),
 				'selectTrigger' => ['description'],
 				'output' => ['name', 'triggerid'],
-				'preservekeys' => true,
+				'preservekeys' => true
 			]);
 
 			foreach ($service['dependencies'] as $dependency) {
@@ -283,7 +283,7 @@ if (hasRequest('form')) {
 					'triggerid' => $child_service['triggerid'],
 					'trigger' => ($child_service['triggerid'] == 0) ? '' : $child_service['trigger']['description'],
 					'serviceid' => $dependency['servicedownid'],
-					'soft' => $dependency['soft'],
+					'soft' => $dependency['soft']
 				];
 			}
 
